/****************************************************************************
** Meta object code from reading C++ file 'GeometryLayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/layers/GeometryLayer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GeometryLayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13GeometryLayerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::GeometryLayer::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13GeometryLayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::GeometryLayer",
        "repaintNeeded",
        "",
        "highlightedPlacemarksChanged",
        "QList<GeoDataPlacemark*>",
        "clickedPlacemarks",
        "addPlacemarks",
        "QModelIndex",
        "index",
        "first",
        "last",
        "removePlacemarks",
        "resetCacheData",
        "setTileLevel",
        "tileLevel",
        "handleHighlight",
        "lon",
        "lat",
        "GeoDataCoordinates::Unit",
        "unit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highlightedPlacemarksChanged'
        QtMocHelpers::SignalData<void(const QList<GeoDataPlacemark*> &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'addPlacemarks'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'removePlacemarks'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'resetCacheData'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTileLevel'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'handleHighlight'
        QtMocHelpers::SlotData<void(qreal, qreal, GeoDataCoordinates::Unit)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 }, { QMetaType::QReal, 17 }, { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeometryLayer, qt_meta_tag_ZN6Marble13GeometryLayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::GeometryLayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13GeometryLayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13GeometryLayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13GeometryLayerE_t>.metaTypes,
    nullptr
} };

void Marble::GeometryLayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeometryLayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->repaintNeeded(); break;
        case 1: _t->highlightedPlacemarksChanged((*reinterpret_cast<std::add_pointer_t<QList<GeoDataPlacemark*>>>(_a[1]))); break;
        case 2: _t->addPlacemarks((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->removePlacemarks((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->resetCacheData(); break;
        case 5: _t->setTileLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->handleHighlight((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeometryLayer::*)()>(_a, &GeometryLayer::repaintNeeded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeometryLayer::*)(const QList<GeoDataPlacemark*> & )>(_a, &GeometryLayer::highlightedPlacemarksChanged, 1))
            return;
    }
}

const QMetaObject *Marble::GeometryLayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::GeometryLayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13GeometryLayerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "LayerInterface"))
        return static_cast< LayerInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::GeometryLayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Marble::GeometryLayer::repaintNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::GeometryLayer::highlightedPlacemarksChanged(const QList<GeoDataPlacemark*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
