/********************************************************************************
** Form generated from reading UI file 'FormattedTextWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORMATTEDTEXTWIDGET_H
#define UI_FORMATTEDTEXTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_FormattedTextWidget
{
public:
    QAction *m_actionBold;
    QAction *m_actionItalics;
    QAction *m_actionUnderlined;
    QAction *m_actionAddImage;
    QAction *m_actionAddLink;
    QAction *m_actionColor;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *m_isFormattedTextMode;
    QFontComboBox *m_fontFamily;
    QComboBox *m_fontSize;
    QToolBar *m_formattedTextToolBar;
    QSpacerItem *horizontalSpacer;
    QTextEdit *m_description;

    void setupUi(QWidget *FormattedTextWidget)
    {
        if (FormattedTextWidget->objectName().isEmpty())
            FormattedTextWidget->setObjectName("FormattedTextWidget");
        FormattedTextWidget->resize(645, 300);
        m_actionBold = new QAction(FormattedTextWidget);
        m_actionBold->setObjectName("m_actionBold");
        m_actionBold->setCheckable(true);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/format-text-bold.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionBold->setIcon(icon);
        m_actionItalics = new QAction(FormattedTextWidget);
        m_actionItalics->setObjectName("m_actionItalics");
        m_actionItalics->setCheckable(true);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/format-text-italic.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionItalics->setIcon(icon1);
        m_actionUnderlined = new QAction(FormattedTextWidget);
        m_actionUnderlined->setObjectName("m_actionUnderlined");
        m_actionUnderlined->setCheckable(true);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/format-text-underline.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionUnderlined->setIcon(icon2);
        m_actionAddImage = new QAction(FormattedTextWidget);
        m_actionAddImage->setObjectName("m_actionAddImage");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/insert-image.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionAddImage->setIcon(icon3);
        m_actionAddLink = new QAction(FormattedTextWidget);
        m_actionAddLink->setObjectName("m_actionAddLink");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/icons/insert-link.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        m_actionAddLink->setIcon(icon4);
        m_actionColor = new QAction(FormattedTextWidget);
        m_actionColor->setObjectName("m_actionColor");
        verticalLayout = new QVBoxLayout(FormattedTextWidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_isFormattedTextMode = new QCheckBox(FormattedTextWidget);
        m_isFormattedTextMode->setObjectName("m_isFormattedTextMode");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_isFormattedTextMode->sizePolicy().hasHeightForWidth());
        m_isFormattedTextMode->setSizePolicy(sizePolicy);
        m_isFormattedTextMode->setMinimumSize(QSize(135, 0));
        m_isFormattedTextMode->setChecked(true);

        horizontalLayout->addWidget(m_isFormattedTextMode);

        m_fontFamily = new QFontComboBox(FormattedTextWidget);
        m_fontFamily->setObjectName("m_fontFamily");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_fontFamily->sizePolicy().hasHeightForWidth());
        m_fontFamily->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(m_fontFamily);

        m_fontSize = new QComboBox(FormattedTextWidget);
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->addItem(QString());
        m_fontSize->setObjectName("m_fontSize");
        m_fontSize->setEditable(true);

        horizontalLayout->addWidget(m_fontSize);

        m_formattedTextToolBar = new QToolBar(FormattedTextWidget);
        m_formattedTextToolBar->setObjectName("m_formattedTextToolBar");

        horizontalLayout->addWidget(m_formattedTextToolBar);

        horizontalSpacer = new QSpacerItem(13, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        m_description = new QTextEdit(FormattedTextWidget);
        m_description->setObjectName("m_description");

        verticalLayout->addWidget(m_description);


        m_formattedTextToolBar->addSeparator();
        m_formattedTextToolBar->addAction(m_actionBold);
        m_formattedTextToolBar->addAction(m_actionItalics);
        m_formattedTextToolBar->addAction(m_actionUnderlined);
        m_formattedTextToolBar->addAction(m_actionColor);
        m_formattedTextToolBar->addAction(m_actionAddImage);
        m_formattedTextToolBar->addAction(m_actionAddLink);

        retranslateUi(FormattedTextWidget);

        QMetaObject::connectSlotsByName(FormattedTextWidget);
    } // setupUi

    void retranslateUi(QWidget *FormattedTextWidget)
    {
        m_actionBold->setText(QCoreApplication::translate("FormattedTextWidget", "Bold", nullptr));
#if QT_CONFIG(tooltip)
        m_actionBold->setToolTip(QCoreApplication::translate("FormattedTextWidget", "Bold", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionItalics->setText(QCoreApplication::translate("FormattedTextWidget", "Italics", nullptr));
#if QT_CONFIG(tooltip)
        m_actionItalics->setToolTip(QCoreApplication::translate("FormattedTextWidget", "Italics", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionUnderlined->setText(QCoreApplication::translate("FormattedTextWidget", "Underlined", nullptr));
#if QT_CONFIG(tooltip)
        m_actionUnderlined->setToolTip(QCoreApplication::translate("FormattedTextWidget", "Underlined", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionAddImage->setText(QCoreApplication::translate("FormattedTextWidget", "Add image", nullptr));
#if QT_CONFIG(tooltip)
        m_actionAddImage->setToolTip(QCoreApplication::translate("FormattedTextWidget", "Add image", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionAddLink->setText(QCoreApplication::translate("FormattedTextWidget", "Add link", nullptr));
#if QT_CONFIG(tooltip)
        m_actionAddLink->setToolTip(QCoreApplication::translate("FormattedTextWidget", "Add link", nullptr));
#endif // QT_CONFIG(tooltip)
        m_actionColor->setText(QCoreApplication::translate("FormattedTextWidget", "Color", nullptr));
        m_isFormattedTextMode->setText(QCoreApplication::translate("FormattedTextWidget", "Formatted text", nullptr));
        m_fontSize->setItemText(0, QCoreApplication::translate("FormattedTextWidget", "6", nullptr));
        m_fontSize->setItemText(1, QCoreApplication::translate("FormattedTextWidget", "8", nullptr));
        m_fontSize->setItemText(2, QCoreApplication::translate("FormattedTextWidget", "9", nullptr));
        m_fontSize->setItemText(3, QCoreApplication::translate("FormattedTextWidget", "10", nullptr));
        m_fontSize->setItemText(4, QCoreApplication::translate("FormattedTextWidget", "11", nullptr));
        m_fontSize->setItemText(5, QCoreApplication::translate("FormattedTextWidget", "12", nullptr));
        m_fontSize->setItemText(6, QCoreApplication::translate("FormattedTextWidget", "14", nullptr));
        m_fontSize->setItemText(7, QCoreApplication::translate("FormattedTextWidget", "16", nullptr));
        m_fontSize->setItemText(8, QCoreApplication::translate("FormattedTextWidget", "18", nullptr));
        m_fontSize->setItemText(9, QCoreApplication::translate("FormattedTextWidget", "20", nullptr));
        m_fontSize->setItemText(10, QCoreApplication::translate("FormattedTextWidget", "24", nullptr));
        m_fontSize->setItemText(11, QCoreApplication::translate("FormattedTextWidget", "36", nullptr));
        m_fontSize->setItemText(12, QCoreApplication::translate("FormattedTextWidget", "48", nullptr));
        m_fontSize->setItemText(13, QCoreApplication::translate("FormattedTextWidget", "72", nullptr));
        m_fontSize->setItemText(14, QCoreApplication::translate("FormattedTextWidget", "96", nullptr));

        m_formattedTextToolBar->setWindowTitle(QCoreApplication::translate("FormattedTextWidget", "toolBar", nullptr));
        (void)FormattedTextWidget;
    } // retranslateUi

};

namespace Ui {
    class FormattedTextWidget: public Ui_FormattedTextWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FORMATTEDTEXTWIDGET_H
