/********************************************************************************
** Form generated from reading UI file 'OpenDesktopConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENDESKTOPCONFIGWIDGET_H
#define UI_OPENDESKTOPCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_OpenDesktopConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *m_displayedItemsLabel;
    QSpinBox *m_itemsOnScreenSpin;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *OpenDesktopConfigWidget)
    {
        if (OpenDesktopConfigWidget->objectName().isEmpty())
            OpenDesktopConfigWidget->setObjectName("OpenDesktopConfigWidget");
        OpenDesktopConfigWidget->resize(400, 240);
        verticalLayout = new QVBoxLayout(OpenDesktopConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        m_displayedItemsLabel = new QLabel(OpenDesktopConfigWidget);
        m_displayedItemsLabel->setObjectName("m_displayedItemsLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_displayedItemsLabel);

        m_itemsOnScreenSpin = new QSpinBox(OpenDesktopConfigWidget);
        m_itemsOnScreenSpin->setObjectName("m_itemsOnScreenSpin");
        m_itemsOnScreenSpin->setMinimum(1);
        m_itemsOnScreenSpin->setMaximum(1000);
        m_itemsOnScreenSpin->setValue(15);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_itemsOnScreenSpin);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(OpenDesktopConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(OpenDesktopConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, OpenDesktopConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, OpenDesktopConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OpenDesktopConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *OpenDesktopConfigWidget)
    {
        OpenDesktopConfigWidget->setWindowTitle(QCoreApplication::translate("OpenDesktopConfigWidget", "OpenDesktop plugin configuration", nullptr));
        m_displayedItemsLabel->setText(QCoreApplication::translate("OpenDesktopConfigWidget", "Number of displayed items on the screen:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenDesktopConfigWidget: public Ui_OpenDesktopConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENDESKTOPCONFIGWIDGET_H
