/********************************************************************************
** Form generated from reading UI file 'WikipediaConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIKIPEDIACONFIGWIDGET_H
#define UI_WIKIPEDIACONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_WikipediaConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *m_showThumbnailCheckBox;
    QHBoxLayout *horizontalLayout;
    QLabel *m_itemNumberLabel;
    QSpacerItem *horizontalSpacer;
    QSpinBox *m_itemNumberSpinBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *WikipediaConfigWidget)
    {
        if (WikipediaConfigWidget->objectName().isEmpty())
            WikipediaConfigWidget->setObjectName("WikipediaConfigWidget");
        WikipediaConfigWidget->resize(328, 267);
        verticalLayout = new QVBoxLayout(WikipediaConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_showThumbnailCheckBox = new QCheckBox(WikipediaConfigWidget);
        m_showThumbnailCheckBox->setObjectName("m_showThumbnailCheckBox");
        m_showThumbnailCheckBox->setChecked(true);

        verticalLayout->addWidget(m_showThumbnailCheckBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_itemNumberLabel = new QLabel(WikipediaConfigWidget);
        m_itemNumberLabel->setObjectName("m_itemNumberLabel");

        horizontalLayout->addWidget(m_itemNumberLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_itemNumberSpinBox = new QSpinBox(WikipediaConfigWidget);
        m_itemNumberSpinBox->setObjectName("m_itemNumberSpinBox");

        horizontalLayout->addWidget(m_itemNumberSpinBox);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 164, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(WikipediaConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(WikipediaConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, WikipediaConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, WikipediaConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(WikipediaConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *WikipediaConfigWidget)
    {
        WikipediaConfigWidget->setWindowTitle(QCoreApplication::translate("WikipediaConfigWidget", "Configure Wikipedia Plugin", nullptr));
        m_showThumbnailCheckBox->setText(QCoreApplication::translate("WikipediaConfigWidget", "Show thumbnail images", nullptr));
        m_itemNumberLabel->setText(QCoreApplication::translate("WikipediaConfigWidget", "Number of items on the screen", nullptr));
    } // retranslateUi

};

namespace Ui {
    class WikipediaConfigWidget: public Ui_WikipediaConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WIKIPEDIACONFIGWIDGET_H
