/********************************************************************************
** Form generated from reading UI file 'SunControlWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SUNCONTROLWIDGET_H
#define UI_SUNCONTROLWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SunControlWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *sunShading;
    QVBoxLayout *verticalLayout;
    QRadioButton *showShadow;
    QRadioButton *showNightMap;
    QGroupBox *sunZenith;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *subSolarIconCheckBox;
    QLabel *subSolarIconLabel;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *lockToSubSolarPointCheckBox;
    QLabel *lockToSubSolarPointLabel;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lockWarningLabel;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SunControlWidget)
    {
        if (SunControlWidget->objectName().isEmpty())
            SunControlWidget->setObjectName("SunControlWidget");
        SunControlWidget->resize(333, 399);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SunControlWidget->sizePolicy().hasHeightForWidth());
        SunControlWidget->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(SunControlWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        sunShading = new QGroupBox(SunControlWidget);
        sunShading->setObjectName("sunShading");
        sunShading->setCheckable(true);
        sunShading->setChecked(false);
        verticalLayout = new QVBoxLayout(sunShading);
        verticalLayout->setObjectName("verticalLayout");
        showShadow = new QRadioButton(sunShading);
        showShadow->setObjectName("showShadow");
        showShadow->setChecked(true);

        verticalLayout->addWidget(showShadow);

        showNightMap = new QRadioButton(sunShading);
        showNightMap->setObjectName("showNightMap");

        verticalLayout->addWidget(showNightMap);


        verticalLayout_2->addWidget(sunShading);

        sunZenith = new QGroupBox(SunControlWidget);
        sunZenith->setObjectName("sunZenith");
        sunZenith->setCheckable(false);
        verticalLayout_3 = new QVBoxLayout(sunZenith);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        subSolarIconCheckBox = new QCheckBox(sunZenith);
        subSolarIconCheckBox->setObjectName("subSolarIconCheckBox");

        horizontalLayout_2->addWidget(subSolarIconCheckBox);

        subSolarIconLabel = new QLabel(sunZenith);
        subSolarIconLabel->setObjectName("subSolarIconLabel");
        subSolarIconLabel->setOpenExternalLinks(true);

        horizontalLayout_2->addWidget(subSolarIconLabel);

        horizontalSpacer_2 = new QSpacerItem(125, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lockToSubSolarPointCheckBox = new QCheckBox(sunZenith);
        lockToSubSolarPointCheckBox->setObjectName("lockToSubSolarPointCheckBox");

        horizontalLayout_3->addWidget(lockToSubSolarPointCheckBox);

        lockToSubSolarPointLabel = new QLabel(sunZenith);
        lockToSubSolarPointLabel->setObjectName("lockToSubSolarPointLabel");
        lockToSubSolarPointLabel->setOpenExternalLinks(true);

        horizontalLayout_3->addWidget(lockToSubSolarPointLabel);

        horizontalSpacer_3 = new QSpacerItem(75, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout_3->addLayout(horizontalLayout_3);

        verticalSpacer = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_5 = new QSpacerItem(25, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);

        lockWarningLabel = new QLabel(sunZenith);
        lockWarningLabel->setObjectName("lockWarningLabel");
        lockWarningLabel->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lockWarningLabel->sizePolicy().hasHeightForWidth());
        lockWarningLabel->setSizePolicy(sizePolicy1);
        lockWarningLabel->setStyleSheet(QString::fromUtf8("QLabel { background-color : #e85752; color : white; }\""));
        lockWarningLabel->setWordWrap(true);
        lockWarningLabel->setMargin(7);

        horizontalLayout_4->addWidget(lockWarningLabel);

        horizontalSpacer_4 = new QSpacerItem(10, 65, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        verticalLayout_3->addLayout(horizontalLayout_4);

        verticalSpacer_3 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_3);


        verticalLayout_2->addWidget(sunZenith);

        verticalSpacer_2 = new QSpacerItem(10, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        buttonBox = new QDialogButtonBox(SunControlWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        subSolarIconLabel->setBuddy(subSolarIconCheckBox);
        lockToSubSolarPointLabel->setBuddy(lockToSubSolarPointCheckBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SunControlWidget);
        QObject::connect(lockToSubSolarPointCheckBox, &QCheckBox::toggled, lockWarningLabel, &QLabel::setVisible);

        QMetaObject::connectSlotsByName(SunControlWidget);
    } // setupUi

    void retranslateUi(QDialog *SunControlWidget)
    {
        SunControlWidget->setWindowTitle(QCoreApplication::translate("SunControlWidget", "Sun Control", nullptr));
        sunShading->setTitle(QCoreApplication::translate("SunControlWidget", "S&un Shading", nullptr));
#if QT_CONFIG(tooltip)
        showShadow->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        showShadow->setText(QCoreApplication::translate("SunControlWidget", "Sha&dow", nullptr));
#if QT_CONFIG(tooltip)
        showNightMap->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        showNightMap->setText(QCoreApplication::translate("SunControlWidget", "&Night Map", nullptr));
        sunZenith->setTitle(QCoreApplication::translate("SunControlWidget", "Subsolar Point", nullptr));
#if QT_CONFIG(tooltip)
        subSolarIconCheckBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        subSolarIconCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        subSolarIconLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        subSolarIconLabel->setText(QCoreApplication::translate("SunControlWidget", "Display <a href=\"https://en.wikipedia.org/wiki/Subsolar_point\">Subsolar Point</a> icon", nullptr));
#if QT_CONFIG(tooltip)
        lockToSubSolarPointCheckBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lockToSubSolarPointCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        lockToSubSolarPointLabel->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lockToSubSolarPointLabel->setText(QCoreApplication::translate("SunControlWidget", "<b>Lock</b> map view to <a href=\"https://en.wikipedia.org/wiki/Subsolar_point\">Subsolar Point</a>.", nullptr));
        lockWarningLabel->setText(QCoreApplication::translate("SunControlWidget", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Attention: Panning the map is disabled now! </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Uncheck the &quot;Lock map view to Subsolar Point&quot; option to allow for viewing a different place on the globe again.</p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SunControlWidget: public Ui_SunControlWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SUNCONTROLWIDGET_H
