/****************************************************************************
** Meta object code from reading C++ file 'FlightGearPositionProviderPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/plugins/positionprovider/flightgear/FlightGearPositionProviderPlugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FlightGearPositionProviderPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::FlightGearPositionProviderPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::FlightGearPositionProviderPlugin",
        "readPendingDatagrams",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'readPendingDatagrams'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FlightGearPositionProviderPlugin, qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::FlightGearPositionProviderPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<PositionProviderPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>.metaTypes,
    nullptr
} };

void Marble::FlightGearPositionProviderPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlightGearPositionProviderPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readPendingDatagrams(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Marble::FlightGearPositionProviderPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::FlightGearPositionProviderPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble32FlightGearPositionProviderPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.Marble.PositionProviderPluginInterface/1.02"))
        return static_cast< Marble::PositionProviderPluginInterface*>(this);
    return PositionProviderPlugin::qt_metacast(_clname);
}

int Marble::FlightGearPositionProviderPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PositionProviderPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
using namespace Marble;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_FlightGearPositionProviderPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2f,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'F',  'l',  'i',  'g',  'h',  't', 
    'G',  'e',  'a',  'r',  'P',  'o',  's',  'i', 
    't',  'i',  'o',  'n',  'P',  'r',  'o',  'v', 
    'i',  'd',  'e',  'r',  'P',  'l',  'u',  'g', 
    'i',  'n', 
    // "className"
    0x03,  0x78,  0x20,  'F',  'l',  'i',  'g',  'h', 
    't',  'G',  'e',  'a',  'r',  'P',  'o',  's', 
    'i',  't',  'i',  'o',  'n',  'P',  'r',  'o', 
    'v',  'i',  'd',  'e',  'r',  'P',  'l',  'u', 
    'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(Marble::FlightGearPositionProviderPlugin, FlightGearPositionProviderPlugin, qt_pluginMetaDataV2_FlightGearPositionProviderPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_FlightGearPositionProviderPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x2f,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'F',  'l',  'i',  'g',  'h',  't', 
    'G',  'e',  'a',  'r',  'P',  'o',  's',  'i', 
    't',  'i',  'o',  'n',  'P',  'r',  'o',  'v', 
    'i',  'd',  'e',  'r',  'P',  'l',  'u',  'g', 
    'i',  'n', 
    // "className"
    0x03,  0x78,  0x20,  'F',  'l',  'i',  'g',  'h', 
    't',  'G',  'e',  'a',  'r',  'P',  'o',  's', 
    'i',  't',  'i',  'o',  'n',  'P',  'r',  'o', 
    'v',  'i',  'd',  'e',  'r',  'P',  'l',  'u', 
    'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(Marble::FlightGearPositionProviderPlugin, FlightGearPositionProviderPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
