/********************************************************************************
** Form generated from reading UI file 'PlacemarkEditHeader.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLACEMARKEDITHEADER_H
#define UI_PLACEMARKEDITHEADER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "LatLonEdit.h"

QT_BEGIN_NAMESPACE

class Ui_PlacemarkEditHeaderPrivate
{
public:
    QFormLayout *formLayout_2;
    QHBoxLayout *horizontalLayout;
    QPushButton *iconLinkButton;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    QLineEdit *m_name;
    QLabel *iconLinkLabel;
    QLineEdit *m_iconLink;
    QLabel *idLabel;
    QLineEdit *m_id;
    QComboBox *m_targetId;
    QLabel *targetIdLabel;
    QLabel *positionLabel;
    QHBoxLayout *latLonLayout;
    Marble::LatLonEdit *m_longitude;
    Marble::LatLonEdit *m_latitude;

    void setupUi(QWidget *PlacemarkEditHeaderPrivate)
    {
        if (PlacemarkEditHeaderPrivate->objectName().isEmpty())
            PlacemarkEditHeaderPrivate->setObjectName("PlacemarkEditHeaderPrivate");
        PlacemarkEditHeaderPrivate->resize(302, 126);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PlacemarkEditHeaderPrivate->sizePolicy().hasHeightForWidth());
        PlacemarkEditHeaderPrivate->setSizePolicy(sizePolicy);
        formLayout_2 = new QFormLayout(PlacemarkEditHeaderPrivate);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        iconLinkButton = new QPushButton(PlacemarkEditHeaderPrivate);
        iconLinkButton->setObjectName("iconLinkButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(iconLinkButton->sizePolicy().hasHeightForWidth());
        iconLinkButton->setSizePolicy(sizePolicy1);
        iconLinkButton->setMinimumSize(QSize(85, 85));
        iconLinkButton->setMaximumSize(QSize(85, 85));
        iconLinkButton->setIconSize(QSize(75, 75));

        horizontalLayout->addWidget(iconLinkButton);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        nameLabel = new QLabel(PlacemarkEditHeaderPrivate);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, nameLabel);

        m_name = new QLineEdit(PlacemarkEditHeaderPrivate);
        m_name->setObjectName("m_name");
        QFont font;
        font.setBold(true);
        m_name->setFont(font);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_name);

        iconLinkLabel = new QLabel(PlacemarkEditHeaderPrivate);
        iconLinkLabel->setObjectName("iconLinkLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, iconLinkLabel);

        m_iconLink = new QLineEdit(PlacemarkEditHeaderPrivate);
        m_iconLink->setObjectName("m_iconLink");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_iconLink);

        idLabel = new QLabel(PlacemarkEditHeaderPrivate);
        idLabel->setObjectName("idLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, idLabel);

        m_id = new QLineEdit(PlacemarkEditHeaderPrivate);
        m_id->setObjectName("m_id");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_id);

        m_targetId = new QComboBox(PlacemarkEditHeaderPrivate);
        m_targetId->setObjectName("m_targetId");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, m_targetId);

        targetIdLabel = new QLabel(PlacemarkEditHeaderPrivate);
        targetIdLabel->setObjectName("targetIdLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, targetIdLabel);


        horizontalLayout->addLayout(formLayout);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::SpanningRole, horizontalLayout);

        positionLabel = new QLabel(PlacemarkEditHeaderPrivate);
        positionLabel->setObjectName("positionLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, positionLabel);

        latLonLayout = new QHBoxLayout();
        latLonLayout->setObjectName("latLonLayout");
        latLonLayout->setContentsMargins(0, 0, 0, 0);
        m_longitude = new Marble::LatLonEdit(PlacemarkEditHeaderPrivate);
        m_longitude->setObjectName("m_longitude");

        latLonLayout->addWidget(m_longitude);

        m_latitude = new Marble::LatLonEdit(PlacemarkEditHeaderPrivate);
        m_latitude->setObjectName("m_latitude");

        latLonLayout->addWidget(m_latitude);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, latLonLayout);


        retranslateUi(PlacemarkEditHeaderPrivate);

        QMetaObject::connectSlotsByName(PlacemarkEditHeaderPrivate);
    } // setupUi

    void retranslateUi(QWidget *PlacemarkEditHeaderPrivate)
    {
        iconLinkButton->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "Browse\342\200\246", nullptr));
        nameLabel->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "Name:", nullptr));
        iconLinkLabel->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "Icon link:", nullptr));
        idLabel->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "ID:", nullptr));
        targetIdLabel->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "Target ID:", nullptr));
        positionLabel->setText(QCoreApplication::translate("PlacemarkEditHeaderPrivate", "Position:", nullptr));
        (void)PlacemarkEditHeaderPrivate;
    } // retranslateUi

};

namespace Ui {
    class PlacemarkEditHeaderPrivate: public Ui_PlacemarkEditHeaderPrivate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLACEMARKEDITHEADER_H
