/********************************************************************************
** Form generated from reading UI file 'RoutingSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ROUTINGSETTINGSWIDGET_H
#define UI_ROUTINGSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_RoutingSettingsWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QListView *profilesList;
    QVBoxLayout *verticalLayout;
    QPushButton *addButton;
    QPushButton *configureButton;
    QPushButton *removeButton;
    QSpacerItem *verticalSpacer;
    QPushButton *moveUpButton;
    QPushButton *moveDownButton;

    void setupUi(QWidget *RoutingSettingsWidget)
    {
        if (RoutingSettingsWidget->objectName().isEmpty())
            RoutingSettingsWidget->setObjectName("RoutingSettingsWidget");
        RoutingSettingsWidget->resize(400, 300);
        horizontalLayout = new QHBoxLayout(RoutingSettingsWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        profilesList = new QListView(RoutingSettingsWidget);
        profilesList->setObjectName("profilesList");

        horizontalLayout->addWidget(profilesList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addButton = new QPushButton(RoutingSettingsWidget);
        addButton->setObjectName("addButton");

        verticalLayout->addWidget(addButton);

        configureButton = new QPushButton(RoutingSettingsWidget);
        configureButton->setObjectName("configureButton");
        configureButton->setEnabled(false);

        verticalLayout->addWidget(configureButton);

        removeButton = new QPushButton(RoutingSettingsWidget);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(false);

        verticalLayout->addWidget(removeButton);

        verticalSpacer = new QSpacerItem(20, 118, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        moveUpButton = new QPushButton(RoutingSettingsWidget);
        moveUpButton->setObjectName("moveUpButton");
        moveUpButton->setEnabled(false);

        verticalLayout->addWidget(moveUpButton);

        moveDownButton = new QPushButton(RoutingSettingsWidget);
        moveDownButton->setObjectName("moveDownButton");
        moveDownButton->setEnabled(false);

        verticalLayout->addWidget(moveDownButton);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(RoutingSettingsWidget);

        QMetaObject::connectSlotsByName(RoutingSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *RoutingSettingsWidget)
    {
        addButton->setText(QCoreApplication::translate("RoutingSettingsWidget", "&Add\342\200\246", nullptr));
        configureButton->setText(QCoreApplication::translate("RoutingSettingsWidget", "&Configure\342\200\246", nullptr));
        removeButton->setText(QCoreApplication::translate("RoutingSettingsWidget", "&Remove", nullptr));
        moveUpButton->setText(QCoreApplication::translate("RoutingSettingsWidget", "Move &Up", nullptr));
        moveDownButton->setText(QCoreApplication::translate("RoutingSettingsWidget", "Move &Down", nullptr));
        (void)RoutingSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class RoutingSettingsWidget: public Ui_RoutingSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ROUTINGSETTINGSWIDGET_H
