/****************************************************************************
** Meta object code from reading C++ file 'MarbleMap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/MarbleMap.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleMap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble9MarbleMapE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleMap::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble9MarbleMapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleMap",
        "D-Bus Interface",
        "org.kde.MarbleMap",
        "tileLevelChanged",
        "",
        "level",
        "themeChanged",
        "theme",
        "projectionChanged",
        "Projection",
        "radiusChanged",
        "radius",
        "mouseMoveGeoPosition",
        "geoPositionString",
        "mouseClickGeoPosition",
        "lon",
        "lat",
        "GeoDataCoordinates::Unit",
        "framesPerSecond",
        "fps",
        "repaintNeeded",
        "QRegion",
        "dirtyRegion",
        "visibleLatLonAltBoxChanged",
        "GeoDataLatLonAltBox",
        "visibleLatLonAltBox",
        "pluginSettingsChanged",
        "renderPluginInitialized",
        "RenderPlugin*",
        "renderPlugin",
        "renderStatusChanged",
        "RenderStatus",
        "status",
        "renderStateChanged",
        "RenderState",
        "state",
        "highlightedPlacemarksChanged",
        "viewContextChanged",
        "ViewContext",
        "viewContext",
        "visibleRelationTypesChanged",
        "GeoDataRelation::RelationTypes",
        "relationTypes",
        "propertyValueChanged",
        "name",
        "value",
        "paint",
        "GeoPainter&",
        "painter",
        "QRect",
        "dirtyRect",
        "setRadius",
        "setHeading",
        "heading",
        "rotateBy",
        "deltaLon",
        "deltaLat",
        "centerOn",
        "setCenterLatitude",
        "setCenterLongitude",
        "setProjection",
        "projection",
        "setMapThemeId",
        "maptheme",
        "setPropertyValue",
        "setShowOverviewMap",
        "visible",
        "setShowScaleBar",
        "setShowCompass",
        "setShowClouds",
        "setShowSunShading",
        "setShowCityLights",
        "setLockToSubSolarPoint",
        "setSubSolarPointIconVisible",
        "setShowTileId",
        "setShowAtmosphere",
        "setShowCrosshairs",
        "setShowGrid",
        "setShowPlaces",
        "setShowCities",
        "setShowTerrain",
        "setShowOtherPlaces",
        "setShowRelief",
        "setShowIceLayer",
        "setShowBorders",
        "setShowRivers",
        "setShowLakes",
        "setShowFrameRate",
        "setShowRuntimeTrace",
        "showRuntimeTrace",
        "setShowDebugPolygons",
        "showDebugPolygons",
        "setShowDebugBatchRender",
        "showDebugBatchRender",
        "setShowDebugPlacemarks",
        "showDebugPlacemarks",
        "setLevelTagDebugModeEnabled",
        "levelTagDebugModeEnabled",
        "setDebugLevelTag",
        "debugLevelTag",
        "setShowBackground",
        "setVisibleRelationTypes",
        "notifyMouseClick",
        "x",
        "y",
        "clearVolatileTileCache",
        "setVolatileTileCacheLimit",
        "kiloBytes",
        "setDefaultAngleUnit",
        "AngleUnit",
        "angleUnit",
        "setDefaultFont",
        "QFont",
        "font",
        "reload",
        "downloadRegion",
        "QList<TileCoordsPyramid>",
        "highlightRouteRelation",
        "osmId",
        "enabled",
        "updateMapTheme",
        "updateProperty",
        "setDocument",
        "updateTileLevel",
        "addPlugins"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tileLevelChanged'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'projectionChanged'
        QtMocHelpers::SignalData<void(Projection)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 4 },
        }}),
        // Signal 'radiusChanged'
        QtMocHelpers::SignalData<void(int)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'mouseMoveGeoPosition'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'mouseClickGeoPosition'
        QtMocHelpers::SignalData<void(qreal, qreal, GeoDataCoordinates::Unit)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 15 }, { QMetaType::QReal, 16 }, { 0x80000000 | 17, 4 },
        }}),
        // Signal 'framesPerSecond'
        QtMocHelpers::SignalData<void(qreal)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 },
        }}),
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void(const QRegion &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'repaintNeeded'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'visibleLatLonAltBoxChanged'
        QtMocHelpers::SignalData<void(const GeoDataLatLonAltBox &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'pluginSettingsChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderPluginInitialized'
        QtMocHelpers::SignalData<void(RenderPlugin *)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'renderStatusChanged'
        QtMocHelpers::SignalData<void(RenderStatus)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'renderStateChanged'
        QtMocHelpers::SignalData<void(const RenderState &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'highlightedPlacemarksChanged'
        QtMocHelpers::SignalData<void(qreal, qreal, GeoDataCoordinates::Unit)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 4 }, { QMetaType::QReal, 4 }, { 0x80000000 | 17, 4 },
        }}),
        // Signal 'viewContextChanged'
        QtMocHelpers::SignalData<void(ViewContext)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Signal 'visibleRelationTypesChanged'
        QtMocHelpers::SignalData<void(GeoDataRelation::RelationTypes)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Signal 'propertyValueChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::Bool, 45 },
        }}),
        // Slot 'paint'
        QtMocHelpers::SlotData<void(GeoPainter &, const QRect &)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setRadius'
        QtMocHelpers::SlotData<void(int)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setHeading'
        QtMocHelpers::SlotData<void(qreal)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 53 },
        }}),
        // Slot 'rotateBy'
        QtMocHelpers::SlotData<void(qreal, qreal)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 55 }, { QMetaType::QReal, 56 },
        }}),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const qreal, const qreal)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 15 }, { QMetaType::QReal, 16 },
        }}),
        // Slot 'setCenterLatitude'
        QtMocHelpers::SlotData<void(qreal)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 16 },
        }}),
        // Slot 'setCenterLongitude'
        QtMocHelpers::SlotData<void(qreal)>(59, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 15 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(Projection)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 61 },
        }}),
        // Slot 'setMapThemeId'
        QtMocHelpers::SlotData<void(const QString &)>(62, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 63 },
        }}),
        // Slot 'setPropertyValue'
        QtMocHelpers::SlotData<void(const QString &, bool)>(64, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 }, { QMetaType::Bool, 45 },
        }}),
        // Slot 'setShowOverviewMap'
        QtMocHelpers::SlotData<void(bool)>(65, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowScaleBar'
        QtMocHelpers::SlotData<void(bool)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowCompass'
        QtMocHelpers::SlotData<void(bool)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowClouds'
        QtMocHelpers::SlotData<void(bool)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowSunShading'
        QtMocHelpers::SlotData<void(bool)>(70, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowCityLights'
        QtMocHelpers::SlotData<void(bool)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setLockToSubSolarPoint'
        QtMocHelpers::SlotData<void(bool)>(72, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setSubSolarPointIconVisible'
        QtMocHelpers::SlotData<void(bool)>(73, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowTileId'
        QtMocHelpers::SlotData<void(bool)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowAtmosphere'
        QtMocHelpers::SlotData<void(bool)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowCrosshairs'
        QtMocHelpers::SlotData<void(bool)>(76, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowGrid'
        QtMocHelpers::SlotData<void(bool)>(77, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowPlaces'
        QtMocHelpers::SlotData<void(bool)>(78, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowCities'
        QtMocHelpers::SlotData<void(bool)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowTerrain'
        QtMocHelpers::SlotData<void(bool)>(80, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowOtherPlaces'
        QtMocHelpers::SlotData<void(bool)>(81, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowRelief'
        QtMocHelpers::SlotData<void(bool)>(82, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowIceLayer'
        QtMocHelpers::SlotData<void(bool)>(83, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowBorders'
        QtMocHelpers::SlotData<void(bool)>(84, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowRivers'
        QtMocHelpers::SlotData<void(bool)>(85, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowLakes'
        QtMocHelpers::SlotData<void(bool)>(86, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowFrameRate'
        QtMocHelpers::SlotData<void(bool)>(87, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setShowRuntimeTrace'
        QtMocHelpers::SlotData<void(bool)>(88, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'showRuntimeTrace'
        QtMocHelpers::SlotData<bool() const>(89, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugPolygons'
        QtMocHelpers::SlotData<void(bool)>(90, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'showDebugPolygons'
        QtMocHelpers::SlotData<bool() const>(91, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugBatchRender'
        QtMocHelpers::SlotData<void(bool)>(92, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'showDebugBatchRender'
        QtMocHelpers::SlotData<bool() const>(93, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowDebugPlacemarks'
        QtMocHelpers::SlotData<void(bool)>(94, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'showDebugPlacemarks'
        QtMocHelpers::SlotData<bool() const>(95, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setLevelTagDebugModeEnabled'
        QtMocHelpers::SlotData<void(bool)>(96, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'levelTagDebugModeEnabled'
        QtMocHelpers::SlotData<bool() const>(97, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setDebugLevelTag'
        QtMocHelpers::SlotData<void(int)>(98, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'debugLevelTag'
        QtMocHelpers::SlotData<int() const>(99, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setShowBackground'
        QtMocHelpers::SlotData<void(bool)>(100, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setVisibleRelationTypes'
        QtMocHelpers::SlotData<void(GeoDataRelation::RelationTypes)>(101, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'notifyMouseClick'
        QtMocHelpers::SlotData<void(int, int)>(102, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 103 }, { QMetaType::Int, 104 },
        }}),
        // Slot 'clearVolatileTileCache'
        QtMocHelpers::SlotData<void()>(105, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setVolatileTileCacheLimit'
        QtMocHelpers::SlotData<void(quint64)>(106, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 107 },
        }}),
        // Slot 'setDefaultAngleUnit'
        QtMocHelpers::SlotData<void(AngleUnit)>(108, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 109, 110 },
        }}),
        // Slot 'setDefaultFont'
        QtMocHelpers::SlotData<void(const QFont &)>(111, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 112, 113 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(114, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadRegion'
        QtMocHelpers::SlotData<void(QList<TileCoordsPyramid> const &)>(115, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 116, 4 },
        }}),
        // Slot 'highlightRouteRelation'
        QtMocHelpers::SlotData<void(qint64, bool)>(117, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 118 }, { QMetaType::Bool, 119 },
        }}),
        // Slot 'updateMapTheme'
        QtMocHelpers::SlotData<void()>(120, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateProperty'
        QtMocHelpers::SlotData<void(const QString &, bool)>(121, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'setDocument'
        QtMocHelpers::SlotData<void(QString)>(122, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateTileLevel'
        QtMocHelpers::SlotData<void()>(123, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPlugins'
        QtMocHelpers::SlotData<void()>(124, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MarbleMap, qt_meta_tag_ZN6Marble9MarbleMapE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::MarbleMap::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MarbleMapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MarbleMapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble9MarbleMapE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleMap::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleMap *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tileLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->themeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->projectionChanged((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 3: _t->radiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->mouseMoveGeoPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->mouseClickGeoPosition((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        case 6: _t->framesPerSecond((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->repaintNeeded((*reinterpret_cast<std::add_pointer_t<QRegion>>(_a[1]))); break;
        case 8: _t->repaintNeeded(); break;
        case 9: _t->visibleLatLonAltBoxChanged((*reinterpret_cast<std::add_pointer_t<GeoDataLatLonAltBox>>(_a[1]))); break;
        case 10: _t->pluginSettingsChanged(); break;
        case 11: _t->renderPluginInitialized((*reinterpret_cast<std::add_pointer_t<RenderPlugin*>>(_a[1]))); break;
        case 12: _t->renderStatusChanged((*reinterpret_cast<std::add_pointer_t<RenderStatus>>(_a[1]))); break;
        case 13: _t->renderStateChanged((*reinterpret_cast<std::add_pointer_t<RenderState>>(_a[1]))); break;
        case 14: _t->highlightedPlacemarksChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        case 15: _t->viewContextChanged((*reinterpret_cast<std::add_pointer_t<ViewContext>>(_a[1]))); break;
        case 16: _t->visibleRelationTypesChanged((*reinterpret_cast<std::add_pointer_t<GeoDataRelation::RelationTypes>>(_a[1]))); break;
        case 17: _t->propertyValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->paint((*reinterpret_cast<std::add_pointer_t<GeoPainter&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2]))); break;
        case 19: _t->setRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setHeading((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 21: _t->rotateBy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 22: _t->centerOn((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 23: _t->setCenterLatitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 24: _t->setCenterLongitude((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 25: _t->setProjection((*reinterpret_cast<std::add_pointer_t<Projection>>(_a[1]))); break;
        case 26: _t->setMapThemeId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setPropertyValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->setShowOverviewMap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setShowScaleBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setShowCompass((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->setShowClouds((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setShowSunShading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setShowCityLights((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setLockToSubSolarPoint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setSubSolarPointIconVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->setShowTileId((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setShowAtmosphere((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->setShowCrosshairs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->setShowGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->setShowPlaces((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->setShowCities((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->setShowTerrain((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->setShowOtherPlaces((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->setShowRelief((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->setShowIceLayer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->setShowBorders((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->setShowRivers((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->setShowLakes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->setShowFrameRate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->setShowRuntimeTrace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: { bool _r = _t->showRuntimeTrace();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->setShowDebugPolygons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: { bool _r = _t->showDebugPolygons();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->setShowDebugBatchRender((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: { bool _r = _t->showDebugBatchRender();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: _t->setShowDebugPlacemarks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: { bool _r = _t->showDebugPlacemarks();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->setLevelTagDebugModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: { bool _r = _t->levelTagDebugModeEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->setDebugLevelTag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 61: { int _r = _t->debugLevelTag();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->setShowBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->setVisibleRelationTypes((*reinterpret_cast<std::add_pointer_t<GeoDataRelation::RelationTypes>>(_a[1]))); break;
        case 64: _t->notifyMouseClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 65: _t->clearVolatileTileCache(); break;
        case 66: _t->setVolatileTileCacheLimit((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 67: _t->setDefaultAngleUnit((*reinterpret_cast<std::add_pointer_t<AngleUnit>>(_a[1]))); break;
        case 68: _t->setDefaultFont((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 69: _t->reload(); break;
        case 70: _t->downloadRegion((*reinterpret_cast<std::add_pointer_t<QList<TileCoordsPyramid>>>(_a[1]))); break;
        case 71: _t->highlightRouteRelation((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 72: _t->d->updateMapTheme(); break;
        case 73: _t->d->updateProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 74: _t->d->setDocument((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 75: _t->d->updateTileLevel(); break;
        case 76: _t->d->addPlugins(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(int )>(_a, &MarbleMap::tileLevelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const QString & )>(_a, &MarbleMap::themeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(Projection )>(_a, &MarbleMap::projectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(int )>(_a, &MarbleMap::radiusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const QString & )>(_a, &MarbleMap::mouseMoveGeoPosition, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(qreal , qreal , GeoDataCoordinates::Unit )>(_a, &MarbleMap::mouseClickGeoPosition, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(qreal )>(_a, &MarbleMap::framesPerSecond, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const QRegion & )>(_a, &MarbleMap::repaintNeeded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const GeoDataLatLonAltBox & )>(_a, &MarbleMap::visibleLatLonAltBoxChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)()>(_a, &MarbleMap::pluginSettingsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(RenderPlugin * )>(_a, &MarbleMap::renderPluginInitialized, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(RenderStatus )>(_a, &MarbleMap::renderStatusChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const RenderState & )>(_a, &MarbleMap::renderStateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(qreal , qreal , GeoDataCoordinates::Unit )>(_a, &MarbleMap::highlightedPlacemarksChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(ViewContext )>(_a, &MarbleMap::viewContextChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(GeoDataRelation::RelationTypes )>(_a, &MarbleMap::visibleRelationTypesChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleMap::*)(const QString & , bool )>(_a, &MarbleMap::propertyValueChanged, 17))
            return;
    }
}

const QMetaObject *Marble::MarbleMap::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleMap::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9MarbleMapE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::MarbleMap::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 77)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 77;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 77)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 77;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleMap::tileLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::MarbleMap::themeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::MarbleMap::projectionChanged(Projection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::MarbleMap::radiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::MarbleMap::mouseMoveGeoPosition(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::MarbleMap::mouseClickGeoPosition(qreal _t1, qreal _t2, GeoDataCoordinates::Unit _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Marble::MarbleMap::framesPerSecond(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::MarbleMap::repaintNeeded(const QRegion & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 9
void Marble::MarbleMap::visibleLatLonAltBoxChanged(const GeoDataLatLonAltBox & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Marble::MarbleMap::pluginSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Marble::MarbleMap::renderPluginInitialized(RenderPlugin * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Marble::MarbleMap::renderStatusChanged(RenderStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Marble::MarbleMap::renderStateChanged(const RenderState & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Marble::MarbleMap::highlightedPlacemarksChanged(qreal _t1, qreal _t2, GeoDataCoordinates::Unit _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void Marble::MarbleMap::viewContextChanged(ViewContext _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Marble::MarbleMap::visibleRelationTypesChanged(GeoDataRelation::RelationTypes _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Marble::MarbleMap::propertyValueChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}
QT_WARNING_POP
