/********************************************************************************
** Form generated from reading UI file 'SatellitesConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SATELLITESCONFIGDIALOG_H
#define UI_SATELLITESCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SatellitesConfigDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tabSatellites;
    QVBoxLayout *verticalLayout;
    QTreeView *treeView;
    QWidget *tabDataSources;
    QVBoxLayout *verticalLayout_3;
    QWidget *buttonWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *labelLastUpdatedText;
    QLabel *labelLastUpdated;
    QSpacerItem *horizontalSpacer1;
    QPushButton *buttonReloadDataSources;
    QFrame *line1;
    QWidget *widgetCatalogs;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelDataSources;
    QSpacerItem *horizontalSpacer3;
    QToolButton *buttonAddDataSource;
    QToolButton *buttonOpenDataSource;
    QToolButton *buttonRemoveDataSource;
    QListWidget *listDataSources;
    QLabel *label;
    QWidget *tabDisabled;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer1;
    QPushButton *buttonDisabled;
    QSpacerItem *verticalSpacer2;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SatellitesConfigDialog)
    {
        if (SatellitesConfigDialog->objectName().isEmpty())
            SatellitesConfigDialog->setObjectName("SatellitesConfigDialog");
        SatellitesConfigDialog->resize(545, 446);
        verticalLayout_2 = new QVBoxLayout(SatellitesConfigDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tabWidget = new QTabWidget(SatellitesConfigDialog);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setLayoutDirection(Qt::LeftToRight);
        tabSatellites = new QWidget();
        tabSatellites->setObjectName("tabSatellites");
        verticalLayout = new QVBoxLayout(tabSatellites);
        verticalLayout->setObjectName("verticalLayout");
        treeView = new QTreeView(tabSatellites);
        treeView->setObjectName("treeView");
        treeView->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        treeView->setIndentation(25);

        verticalLayout->addWidget(treeView);

        tabWidget->addTab(tabSatellites, QString());
        tabDataSources = new QWidget();
        tabDataSources->setObjectName("tabDataSources");
        verticalLayout_3 = new QVBoxLayout(tabDataSources);
        verticalLayout_3->setObjectName("verticalLayout_3");
        buttonWidget = new QWidget(tabDataSources);
        buttonWidget->setObjectName("buttonWidget");
        buttonWidget->setMinimumSize(QSize(0, 0));
        horizontalLayout = new QHBoxLayout(buttonWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetNoConstraint);
        horizontalLayout->setContentsMargins(0, 5, 0, 5);
        labelLastUpdatedText = new QLabel(buttonWidget);
        labelLastUpdatedText->setObjectName("labelLastUpdatedText");

        horizontalLayout->addWidget(labelLastUpdatedText);

        labelLastUpdated = new QLabel(buttonWidget);
        labelLastUpdated->setObjectName("labelLastUpdated");

        horizontalLayout->addWidget(labelLastUpdated);

        horizontalSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer1);

        buttonReloadDataSources = new QPushButton(buttonWidget);
        buttonReloadDataSources->setObjectName("buttonReloadDataSources");
        buttonReloadDataSources->setEnabled(true);

        horizontalLayout->addWidget(buttonReloadDataSources);


        verticalLayout_3->addWidget(buttonWidget);

        line1 = new QFrame(tabDataSources);
        line1->setObjectName("line1");
        line1->setFrameShape(QFrame::Shape::HLine);
        line1->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_3->addWidget(line1);

        widgetCatalogs = new QWidget(tabDataSources);
        widgetCatalogs->setObjectName("widgetCatalogs");
        horizontalLayout_3 = new QHBoxLayout(widgetCatalogs);
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelDataSources = new QLabel(widgetCatalogs);
        labelDataSources->setObjectName("labelDataSources");

        horizontalLayout_3->addWidget(labelDataSources);

        horizontalSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer3);

        buttonAddDataSource = new QToolButton(widgetCatalogs);
        buttonAddDataSource->setObjectName("buttonAddDataSource");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/bookmark-add-folder.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonAddDataSource->setIcon(icon);

        horizontalLayout_3->addWidget(buttonAddDataSource);

        buttonOpenDataSource = new QToolButton(widgetCatalogs);
        buttonOpenDataSource->setObjectName("buttonOpenDataSource");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/document-open.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonOpenDataSource->setIcon(icon1);

        horizontalLayout_3->addWidget(buttonOpenDataSource);

        buttonRemoveDataSource = new QToolButton(widgetCatalogs);
        buttonRemoveDataSource->setObjectName("buttonRemoveDataSource");
        buttonRemoveDataSource->setEnabled(false);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/bookmark-remove.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonRemoveDataSource->setIcon(icon2);

        horizontalLayout_3->addWidget(buttonRemoveDataSource);


        verticalLayout_3->addWidget(widgetCatalogs);

        listDataSources = new QListWidget(tabDataSources);
        QBrush brush(QColor(0, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::NoBrush);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listDataSources);
        __qlistwidgetitem->setBackground(brush);
        __qlistwidgetitem->setFlags(Qt::NoItemFlags);
        listDataSources->setObjectName("listDataSources");
        QFont font;
        font.setBold(false);
        font.setItalic(false);
        font.setKerning(true);
        listDataSources->setFont(font);

        verticalLayout_3->addWidget(listDataSources);

        label = new QLabel(tabDataSources);
        label->setObjectName("label");
        QFont font1;
        font1.setPointSize(10);
        label->setFont(font1);
        label->setTextFormat(Qt::RichText);
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label->setWordWrap(true);
        label->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label);

        tabWidget->addTab(tabDataSources, QString());
        tabDisabled = new QWidget();
        tabDisabled->setObjectName("tabDisabled");
        tabDisabled->setLayoutDirection(Qt::LeftToRight);
        gridLayout = new QGridLayout(tabDisabled);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetNoConstraint);
        verticalSpacer1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer1, 4, 0, 1, 1);

        buttonDisabled = new QPushButton(tabDisabled);
        buttonDisabled->setObjectName("buttonDisabled");
        buttonDisabled->setMaximumSize(QSize(250, 16777215));
        buttonDisabled->setLayoutDirection(Qt::LeftToRight);
        buttonDisabled->setFlat(false);

        gridLayout->addWidget(buttonDisabled, 3, 0, 1, 1);

        verticalSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer2, 0, 0, 1, 1);

        label_2 = new QLabel(tabDisabled);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        tabWidget->addTab(tabDisabled, QString());

        verticalLayout_2->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(SatellitesConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout_2->addWidget(buttonBox);

        QWidget::setTabOrder(buttonBox, tabWidget);
        QWidget::setTabOrder(tabWidget, treeView);

        retranslateUi(SatellitesConfigDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SatellitesConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SatellitesConfigDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(SatellitesConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *SatellitesConfigDialog)
    {
        SatellitesConfigDialog->setWindowTitle(QCoreApplication::translate("SatellitesConfigDialog", "Satellites Configuration", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSatellites), QCoreApplication::translate("SatellitesConfigDialog", "&Satellites", nullptr));
        labelLastUpdatedText->setText(QCoreApplication::translate("SatellitesConfigDialog", "<html><head/><body><p><span style=\" font-weight:600;\">Last update:</span></p></body></html>", nullptr));
        labelLastUpdated->setText(QCoreApplication::translate("SatellitesConfigDialog", "-", nullptr));
        buttonReloadDataSources->setText(QCoreApplication::translate("SatellitesConfigDialog", "&Reload All Data Sources", nullptr));
        labelDataSources->setText(QCoreApplication::translate("SatellitesConfigDialog", "Satellite Data Sources:", nullptr));
#if QT_CONFIG(tooltip)
        buttonAddDataSource->setToolTip(QCoreApplication::translate("SatellitesConfigDialog", "Add a new data source (URL).", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAddDataSource->setText(QCoreApplication::translate("SatellitesConfigDialog", "+", nullptr));
#if QT_CONFIG(tooltip)
        buttonOpenDataSource->setToolTip(QCoreApplication::translate("SatellitesConfigDialog", "Open a new data source from disk.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonOpenDataSource->setText(QCoreApplication::translate("SatellitesConfigDialog", "-", nullptr));
#if QT_CONFIG(tooltip)
        buttonRemoveDataSource->setToolTip(QCoreApplication::translate("SatellitesConfigDialog", "Remove selected data source.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonRemoveDataSource->setText(QCoreApplication::translate("SatellitesConfigDialog", "\342\200\246", nullptr));

        const bool __sortingEnabled = listDataSources->isSortingEnabled();
        listDataSources->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listDataSources->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("SatellitesConfigDialog", "(Built-in Data Sources for Earth Satellites)", nullptr));
        listDataSources->setSortingEnabled(__sortingEnabled);

        label->setText(QCoreApplication::translate("SatellitesConfigDialog", "<html><head/><body><p>Supported formats: <a href=\"https://techbase.kde.org/Projects/Marble/SatelliteCatalogFormat\"><span style=\" text-decoration: underline; color:#0000ff;\">Marble Satellite Catalogue</span></a>, <a href=\"https://en.wikipedia.org/wiki/Two-line_element_set\"><span style=\" text-decoration: underline; color:#0000ff;\">Two-Line-Element Set</span></a></p></body></html>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDataSources), QCoreApplication::translate("SatellitesConfigDialog", "&Data Sources", nullptr));
        buttonDisabled->setText(QCoreApplication::translate("SatellitesConfigDialog", "&Activate Plugin", nullptr));
        label_2->setText(QCoreApplication::translate("SatellitesConfigDialog", "Configuration options not available since the plugin is disabled at the moment.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDisabled), QCoreApplication::translate("SatellitesConfigDialog", "Plugin Inactive", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SatellitesConfigDialog: public Ui_SatellitesConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SATELLITESCONFIGDIALOG_H
