/****************************************************************************
** Meta object code from reading C++ file 'EditPolygonDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/plugins/render/annotate/EditPolygonDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'EditPolygonDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble17EditPolygonDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::EditPolygonDialog::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::EditPolygonDialog",
        "polygonUpdated",
        "",
        "GeoDataFeature*",
        "feature",
        "relationCreated",
        "OsmPlacemarkData",
        "relation",
        "handleAddingNode",
        "GeoDataCoordinates",
        "node",
        "handleItemMoving",
        "GeoDataPlacemark*",
        "item",
        "handleChangingStyle",
        "updatePolygon",
        "updateLinesDialog",
        "QColor",
        "color",
        "updatePolyDialog",
        "checkFields",
        "restoreInitial",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'polygonUpdated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'relationCreated'
        QtMocHelpers::SignalData<void(const OsmPlacemarkData &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleAddingNode'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'handleItemMoving'
        QtMocHelpers::SlotData<void(GeoDataPlacemark *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'handleChangingStyle'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePolygon'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLinesDialog'
        QtMocHelpers::SlotData<void(const QColor &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'updatePolyDialog'
        QtMocHelpers::SlotData<void(const QColor &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'checkFields'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restoreInitial'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditPolygonDialog, qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::EditPolygonDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>.metaTypes,
    nullptr
} };

void Marble::EditPolygonDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditPolygonDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->polygonUpdated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 1: _t->relationCreated((*reinterpret_cast<std::add_pointer_t<OsmPlacemarkData>>(_a[1]))); break;
        case 2: _t->handleAddingNode((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 3: _t->handleItemMoving((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark*>>(_a[1]))); break;
        case 4: _t->handleChangingStyle(); break;
        case 5: _t->updatePolygon(); break;
        case 6: _t->updateLinesDialog((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 7: _t->updatePolyDialog((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 8: _t->checkFields(); break;
        case 9: _t->restoreInitial((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditPolygonDialog::*)(GeoDataFeature * )>(_a, &EditPolygonDialog::polygonUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditPolygonDialog::*)(const OsmPlacemarkData & )>(_a, &EditPolygonDialog::relationCreated, 1))
            return;
    }
}

const QMetaObject *Marble::EditPolygonDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::EditPolygonDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17EditPolygonDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Marble::EditPolygonDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Marble::EditPolygonDialog::polygonUpdated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::EditPolygonDialog::relationCreated(const OsmPlacemarkData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
