/********************************************************************************
** Form generated from reading UI file 'PositionMarkerConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POSITIONMARKERCONFIGWIDGET_H
#define UI_POSITIONMARKERCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PositionMarkerConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QRadioButton *m_originalCursor;
    QRadioButton *m_customCursor;
    QHBoxLayout *horizontalLayout;
    QToolButton *m_fileChooserButton;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QSlider *m_resizeSlider;
    QLabel *m_sizeLabel;
    QCheckBox *m_trailCheckBox;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *m_accuracyLabel;
    QPushButton *m_acColorChooserButton;
    QLabel *label_2;
    QPushButton *m_trailColorChooserButton;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *m_buttonBox;
    QButtonGroup *m_buttonGroup;

    void setupUi(QDialog *PositionMarkerConfigWidget)
    {
        if (PositionMarkerConfigWidget->objectName().isEmpty())
            PositionMarkerConfigWidget->setObjectName("PositionMarkerConfigWidget");
        PositionMarkerConfigWidget->resize(470, 352);
        verticalLayout_3 = new QVBoxLayout(PositionMarkerConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox = new QGroupBox(PositionMarkerConfigWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_originalCursor = new QRadioButton(groupBox);
        m_buttonGroup = new QButtonGroup(PositionMarkerConfigWidget);
        m_buttonGroup->setObjectName("m_buttonGroup");
        m_buttonGroup->addButton(m_originalCursor);
        m_originalCursor->setObjectName("m_originalCursor");
        m_originalCursor->setChecked(true);

        gridLayout->addWidget(m_originalCursor, 0, 0, 1, 2);

        m_customCursor = new QRadioButton(groupBox);
        m_buttonGroup->addButton(m_customCursor);
        m_customCursor->setObjectName("m_customCursor");

        gridLayout->addWidget(m_customCursor, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_fileChooserButton = new QToolButton(groupBox);
        m_fileChooserButton->setObjectName("m_fileChooserButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_fileChooserButton->sizePolicy().hasHeightForWidth());
        m_fileChooserButton->setSizePolicy(sizePolicy);
        m_fileChooserButton->setMinimumSize(QSize(22, 22));
        m_fileChooserButton->setIconSize(QSize(22, 22));

        horizontalLayout->addWidget(m_fileChooserButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        m_resizeSlider = new QSlider(groupBox);
        m_resizeSlider->setObjectName("m_resizeSlider");
        m_resizeSlider->setMinimum(0);
        m_resizeSlider->setMaximum(0);
        m_resizeSlider->setSingleStep(1);
        m_resizeSlider->setPageStep(1);
        m_resizeSlider->setValue(0);
        m_resizeSlider->setSliderPosition(0);
        m_resizeSlider->setOrientation(Qt::Horizontal);
        m_resizeSlider->setInvertedAppearance(false);
        m_resizeSlider->setTickPosition(QSlider::TicksBelow);
        m_resizeSlider->setTickInterval(1);

        horizontalLayout_2->addWidget(m_resizeSlider);

        m_sizeLabel = new QLabel(groupBox);
        m_sizeLabel->setObjectName("m_sizeLabel");

        horizontalLayout_2->addWidget(m_sizeLabel);


        verticalLayout->addLayout(horizontalLayout_2);

        m_trailCheckBox = new QCheckBox(groupBox);
        m_trailCheckBox->setObjectName("m_trailCheckBox");
        m_trailCheckBox->setChecked(false);

        verticalLayout->addWidget(m_trailCheckBox);


        verticalLayout_3->addWidget(groupBox);

        groupBox_2 = new QGroupBox(PositionMarkerConfigWidget);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        m_accuracyLabel = new QLabel(groupBox_2);
        m_accuracyLabel->setObjectName("m_accuracyLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_accuracyLabel);

        m_acColorChooserButton = new QPushButton(groupBox_2);
        m_acColorChooserButton->setObjectName("m_acColorChooserButton");
        sizePolicy.setHeightForWidth(m_acColorChooserButton->sizePolicy().hasHeightForWidth());
        m_acColorChooserButton->setSizePolicy(sizePolicy);
        m_acColorChooserButton->setMinimumSize(QSize(30, 25));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_acColorChooserButton);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        m_trailColorChooserButton = new QPushButton(groupBox_2);
        m_trailColorChooserButton->setObjectName("m_trailColorChooserButton");
        sizePolicy.setHeightForWidth(m_trailColorChooserButton->sizePolicy().hasHeightForWidth());
        m_trailColorChooserButton->setSizePolicy(sizePolicy);
        m_trailColorChooserButton->setMinimumSize(QSize(30, 25));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_trailColorChooserButton);


        verticalLayout_3->addWidget(groupBox_2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        m_buttonBox = new QDialogButtonBox(PositionMarkerConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        verticalLayout_3->addWidget(m_buttonBox);

#if QT_CONFIG(shortcut)
        m_accuracyLabel->setBuddy(m_acColorChooserButton);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PositionMarkerConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, PositionMarkerConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, PositionMarkerConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(PositionMarkerConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *PositionMarkerConfigWidget)
    {
        PositionMarkerConfigWidget->setWindowTitle(QCoreApplication::translate("PositionMarkerConfigWidget", "Configure Position Marker Plugin", nullptr));
        groupBox->setTitle(QCoreApplication::translate("PositionMarkerConfigWidget", "Cursor Shape", nullptr));
        m_originalCursor->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "&Arrow", nullptr));
        m_customCursor->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "&Custom:", nullptr));
        m_fileChooserButton->setText(QString());
        label->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "Position marker images indicating the direction should point north (top).", nullptr));
        m_sizeLabel->setText(QString());
        m_trailCheckBox->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "Trail", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("PositionMarkerConfigWidget", "C&olors", nullptr));
        m_accuracyLabel->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "&Accuracy:", nullptr));
#if QT_CONFIG(tooltip)
        m_acColorChooserButton->setToolTip(QCoreApplication::translate("PositionMarkerConfigWidget", "Color of the position marker's accuracy indicator.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_acColorChooserButton->setText(QString());
        label_2->setText(QCoreApplication::translate("PositionMarkerConfigWidget", "Trail:", nullptr));
#if QT_CONFIG(tooltip)
        m_trailColorChooserButton->setToolTip(QCoreApplication::translate("PositionMarkerConfigWidget", "Color of the position marker's trail.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_trailColorChooserButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class PositionMarkerConfigWidget: public Ui_PositionMarkerConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_POSITIONMARKERCONFIGWIDGET_H
