/****************************************************************************
** Meta object code from reading C++ file 'VectorTileModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/VectorTileModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'VectorTileModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10TileRunnerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TileRunner::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10TileRunnerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TileRunner",
        "documentLoaded",
        "",
        "TileId",
        "id",
        "GeoDataDocument*",
        "document"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentLoaded'
        QtMocHelpers::SignalData<void(const TileId &, GeoDataDocument *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TileRunner, qt_meta_tag_ZN6Marble10TileRunnerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TileRunner::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileRunnerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileRunnerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10TileRunnerE_t>.metaTypes,
    nullptr
} };

void Marble::TileRunner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TileRunner *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentLoaded((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TileRunner::*)(const TileId & , GeoDataDocument * )>(_a, &TileRunner::documentLoaded, 0))
            return;
    }
}

const QMetaObject *Marble::TileRunner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TileRunner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10TileRunnerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QRunnable"))
        return static_cast< QRunnable*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::TileRunner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Marble::TileRunner::documentLoaded(const TileId & _t1, GeoDataDocument * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN6Marble15VectorTileModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::VectorTileModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble15VectorTileModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::VectorTileModel",
        "tileCompleted",
        "",
        "TileId",
        "tileId",
        "tileAdded",
        "GeoDataDocument*",
        "document",
        "tileRemoved",
        "updateTile",
        "id",
        "clear",
        "cleanupTile",
        "GeoDataObject*",
        "feature"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tileCompleted'
        QtMocHelpers::SignalData<void(const TileId &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'tileAdded'
        QtMocHelpers::SignalData<void(GeoDataDocument *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'tileRemoved'
        QtMocHelpers::SignalData<void(GeoDataDocument *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'updateTile'
        QtMocHelpers::SlotData<void(const TileId &, GeoDataDocument *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 10 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanupTile'
        QtMocHelpers::SlotData<void(GeoDataObject *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VectorTileModel, qt_meta_tag_ZN6Marble15VectorTileModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::VectorTileModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble15VectorTileModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble15VectorTileModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble15VectorTileModelE_t>.metaTypes,
    nullptr
} };

void Marble::VectorTileModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VectorTileModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tileCompleted((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1]))); break;
        case 1: _t->tileAdded((*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[1]))); break;
        case 2: _t->tileRemoved((*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[1]))); break;
        case 3: _t->updateTile((*reinterpret_cast<std::add_pointer_t<TileId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataDocument*>>(_a[2]))); break;
        case 4: _t->clear(); break;
        case 5: _t->cleanupTile((*reinterpret_cast<std::add_pointer_t<GeoDataObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VectorTileModel::*)(const TileId & )>(_a, &VectorTileModel::tileCompleted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VectorTileModel::*)(GeoDataDocument * )>(_a, &VectorTileModel::tileAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VectorTileModel::*)(GeoDataDocument * )>(_a, &VectorTileModel::tileRemoved, 2))
            return;
    }
}

const QMetaObject *Marble::VectorTileModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::VectorTileModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble15VectorTileModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::VectorTileModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Marble::VectorTileModel::tileCompleted(const TileId & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::VectorTileModel::tileAdded(GeoDataDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::VectorTileModel::tileRemoved(GeoDataDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
