/********************************************************************************
** Form generated from reading UI file 'LatLonBoxWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LATLONBOXWIDGET_H
#define UI_LATLONBOXWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_LatLonBoxWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout;
    QDoubleSpinBox *northSpinBox;
    QLabel *northLabel;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_4;
    QDoubleSpinBox *westSpinBox;
    QLabel *westLabel;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QDoubleSpinBox *eastSpinBox;
    QLabel *eastLabel;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_2;
    QDoubleSpinBox *southSpinBox;
    QLabel *southLabel;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *LatLonBoxWidget)
    {
        if (LatLonBoxWidget->objectName().isEmpty())
            LatLonBoxWidget->setObjectName("LatLonBoxWidget");
        LatLonBoxWidget->setEnabled(true);
        LatLonBoxWidget->resize(313, 100);
        gridLayout = new QGridLayout(LatLonBoxWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer_5 = new QSpacerItem(13, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        northSpinBox = new QDoubleSpinBox(LatLonBoxWidget);
        northSpinBox->setObjectName("northSpinBox");
        northSpinBox->setEnabled(true);
        northSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        northSpinBox->setDecimals(3);
        northSpinBox->setMinimum(-90.000000000000000);
        northSpinBox->setMaximum(90.000000000000000);
        northSpinBox->setValue(90.000000000000000);

        horizontalLayout->addWidget(northSpinBox);

        northLabel = new QLabel(LatLonBoxWidget);
        northLabel->setObjectName("northLabel");

        horizontalLayout->addWidget(northLabel);


        gridLayout->addLayout(horizontalLayout, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(13, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 3, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        westSpinBox = new QDoubleSpinBox(LatLonBoxWidget);
        westSpinBox->setObjectName("westSpinBox");
        westSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        westSpinBox->setDecimals(3);
        westSpinBox->setMinimum(-180.000000000000000);
        westSpinBox->setMaximum(180.000000000000000);
        westSpinBox->setValue(-180.000000000000000);

        horizontalLayout_4->addWidget(westSpinBox);

        westLabel = new QLabel(LatLonBoxWidget);
        westLabel->setObjectName("westLabel");

        horizontalLayout_4->addWidget(westLabel);


        gridLayout->addLayout(horizontalLayout_4, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(13, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        eastSpinBox = new QDoubleSpinBox(LatLonBoxWidget);
        eastSpinBox->setObjectName("eastSpinBox");
        eastSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        eastSpinBox->setDecimals(3);
        eastSpinBox->setMinimum(-180.000000000000000);
        eastSpinBox->setMaximum(180.000000000000000);
        eastSpinBox->setValue(180.000000000000000);

        horizontalLayout_3->addWidget(eastSpinBox);

        eastLabel = new QLabel(LatLonBoxWidget);
        eastLabel->setObjectName("eastLabel");

        horizontalLayout_3->addWidget(eastLabel);


        gridLayout->addLayout(horizontalLayout_3, 1, 3, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(13, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 2, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        southSpinBox = new QDoubleSpinBox(LatLonBoxWidget);
        southSpinBox->setObjectName("southSpinBox");
        southSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        southSpinBox->setDecimals(3);
        southSpinBox->setMinimum(-90.000000000000000);
        southSpinBox->setMaximum(90.000000000000000);
        southSpinBox->setValue(-90.000000000000000);

        horizontalLayout_2->addWidget(southSpinBox);

        southLabel = new QLabel(LatLonBoxWidget);
        southLabel->setObjectName("southLabel");

        horizontalLayout_2->addWidget(southLabel);


        gridLayout->addLayout(horizontalLayout_2, 2, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(13, 13, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 2, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 0, 0, 3, 1);

#if QT_CONFIG(shortcut)
        northLabel->setBuddy(northSpinBox);
        westLabel->setBuddy(westSpinBox);
        eastLabel->setBuddy(eastSpinBox);
        southLabel->setBuddy(southSpinBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(northSpinBox, westSpinBox);
        QWidget::setTabOrder(westSpinBox, eastSpinBox);
        QWidget::setTabOrder(eastSpinBox, southSpinBox);

        retranslateUi(LatLonBoxWidget);

        QMetaObject::connectSlotsByName(LatLonBoxWidget);
    } // setupUi

    void retranslateUi(QWidget *LatLonBoxWidget)
    {
        LatLonBoxWidget->setWindowTitle(QCoreApplication::translate("LatLonBoxWidget", "Select a geographic region", nullptr));
#if QT_CONFIG(tooltip)
        northSpinBox->setToolTip(QCoreApplication::translate("LatLonBoxWidget", "Northern Latitude", nullptr));
#endif // QT_CONFIG(tooltip)
        northSpinBox->setSuffix(QCoreApplication::translate("LatLonBoxWidget", "\302\260", nullptr));
        northLabel->setText(QCoreApplication::translate("LatLonBoxWidget", "&N", nullptr));
#if QT_CONFIG(tooltip)
        westSpinBox->setToolTip(QCoreApplication::translate("LatLonBoxWidget", "Western Longitude", nullptr));
#endif // QT_CONFIG(tooltip)
        westSpinBox->setSuffix(QCoreApplication::translate("LatLonBoxWidget", "\302\260", nullptr));
        westLabel->setText(QCoreApplication::translate("LatLonBoxWidget", "&W", nullptr));
#if QT_CONFIG(tooltip)
        eastSpinBox->setToolTip(QCoreApplication::translate("LatLonBoxWidget", "Eastern Longitude", nullptr));
#endif // QT_CONFIG(tooltip)
        eastSpinBox->setSuffix(QCoreApplication::translate("LatLonBoxWidget", "\302\260", nullptr));
        eastLabel->setText(QCoreApplication::translate("LatLonBoxWidget", "&E", nullptr));
#if QT_CONFIG(tooltip)
        southSpinBox->setToolTip(QCoreApplication::translate("LatLonBoxWidget", "Southern Latitude", nullptr));
#endif // QT_CONFIG(tooltip)
        southSpinBox->setSuffix(QCoreApplication::translate("LatLonBoxWidget", "\302\260", nullptr));
        southLabel->setText(QCoreApplication::translate("LatLonBoxWidget", "&S", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LatLonBoxWidget: public Ui_LatLonBoxWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LATLONBOXWIDGET_H
