/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<Bookmarks.h>)
#  include <Bookmarks.h>
#endif
#if __has_include(<Coordinate.h>)
#  include <Coordinate.h>
#endif
#if __has_include(<MarbleDeclarativeObject.h>)
#  include <MarbleDeclarativeObject.h>
#endif
#if __has_include(<MarbleQuickItem.h>)
#  include <MarbleQuickItem.h>
#endif
#if __has_include(<Navigation.h>)
#  include <Navigation.h>
#endif
#if __has_include(<Placemark.h>)
#  include <Placemark.h>
#endif
#if __has_include(<PositionSource.h>)
#  include <PositionSource.h>
#endif
#if __has_include(<RouteRequestModel.h>)
#  include <RouteRequestModel.h>
#endif
#if __has_include(<Routing.h>)
#  include <Routing.h>
#endif
#if __has_include(<SearchBackend.h>)
#  include <SearchBackend.h>
#endif
#if __has_include(<Settings.h>)
#  include <Settings.h>
#endif
#if __has_include(<Tracking.h>)
#  include <Tracking.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_marble()
{
    qmlRegisterModule("org.kde.marble", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Coordinate>("org.kde.marble", 254);
    qmlRegisterEnum<Coordinate::Notation>("Coordinate::Notation");
    qmlRegisterTypesAndRevisions<Marble::Bookmarks>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Marble::MarbleQuickItem>("org.kde.marble", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.marble", 254);
    qmlRegisterEnum<Marble::MarbleQuickItem::Projection>("Marble::MarbleQuickItem::Projection");
    qmlRegisterTypesAndRevisions<Marble::Navigation>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Marble::Placemark>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Marble::PositionSource>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Marble::Routing>("org.kde.marble", 254);
    qmlRegisterEnum<Marble::Routing::RoutingProfile>("Marble::Routing::RoutingProfile");
    qmlRegisterTypesAndRevisions<Marble::SearchBackend>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Marble::Tracking>("org.kde.marble", 254);
    qmlRegisterEnum<Marble::Tracking::PositionMarkerType>("Marble::Tracking::PositionMarkerType");
    qmlRegisterTypesAndRevisions<MarbleDeclarativeObject>("org.kde.marble", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<RouteRequestModel>("org.kde.marble", 254);
    qmlRegisterTypesAndRevisions<Settings>("org.kde.marble", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.marble", 254, 254);
}

static const QQmlModuleRegistration orgkdemarbleRegistration("org.kde.marble", qml_register_types_org_kde_marble);
