/****************************************************************************
** Meta object code from reading C++ file 'AutoNavigation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/AutoNavigation.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AutoNavigation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble14AutoNavigationE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::AutoNavigation::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble14AutoNavigationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::AutoNavigation",
        "recenterModeChanged",
        "",
        "AutoNavigation::CenterMode",
        "mode",
        "autoZoomToggled",
        "enabled",
        "zoomIn",
        "FlyToMode",
        "zoomOut",
        "centerOn",
        "GeoDataCoordinates",
        "position",
        "animated",
        "adjust",
        "speed",
        "inhibitAutoAdjustments"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recenterModeChanged'
        QtMocHelpers::SignalData<void(AutoNavigation::CenterMode)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'autoZoomToggled'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'zoomIn'
        QtMocHelpers::SignalData<void(FlyToMode)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'zoomOut'
        QtMocHelpers::SignalData<void(FlyToMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'centerOn'
        QtMocHelpers::SignalData<void(const GeoDataCoordinates &, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'adjust'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &, qreal)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QReal, 15 },
        }}),
        // Slot 'inhibitAutoAdjustments'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AutoNavigation, qt_meta_tag_ZN6Marble14AutoNavigationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::AutoNavigation::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AutoNavigationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AutoNavigationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble14AutoNavigationE_t>.metaTypes,
    nullptr
} };

void Marble::AutoNavigation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AutoNavigation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recenterModeChanged((*reinterpret_cast<std::add_pointer_t<AutoNavigation::CenterMode>>(_a[1]))); break;
        case 1: _t->autoZoomToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 3: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<FlyToMode>>(_a[1]))); break;
        case 4: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->adjust((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 6: _t->inhibitAutoAdjustments(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AutoNavigation::*)(AutoNavigation::CenterMode )>(_a, &AutoNavigation::recenterModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoNavigation::*)(bool )>(_a, &AutoNavigation::autoZoomToggled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoNavigation::*)(FlyToMode )>(_a, &AutoNavigation::zoomIn, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoNavigation::*)(FlyToMode )>(_a, &AutoNavigation::zoomOut, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutoNavigation::*)(const GeoDataCoordinates & , bool )>(_a, &AutoNavigation::centerOn, 4))
            return;
    }
}

const QMetaObject *Marble::AutoNavigation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::AutoNavigation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AutoNavigationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::AutoNavigation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Marble::AutoNavigation::recenterModeChanged(AutoNavigation::CenterMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Marble::AutoNavigation::autoZoomToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::AutoNavigation::zoomIn(FlyToMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::AutoNavigation::zoomOut(FlyToMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::AutoNavigation::centerOn(const GeoDataCoordinates & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
