/********************************************************************************
** Form generated from reading UI file 'CompassConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPASSCONFIGWIDGET_H
#define UI_COMPASSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CompassConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QListWidget *m_themeList;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *CompassConfigWidget)
    {
        if (CompassConfigWidget->objectName().isEmpty())
            CompassConfigWidget->setObjectName("CompassConfigWidget");
        CompassConfigWidget->resize(365, 185);
        verticalLayout_3 = new QVBoxLayout(CompassConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label = new QLabel(CompassConfigWidget);
        label->setObjectName("label");

        verticalLayout_3->addWidget(label);

        m_themeList = new QListWidget(CompassConfigWidget);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/compass.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(m_themeList);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/compass-arrows.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/compass-atom.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/compass-magnet.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(m_themeList);
        __qlistwidgetitem3->setIcon(icon3);
        m_themeList->setObjectName("m_themeList");
        m_themeList->setIconSize(QSize(64, 64));
        m_themeList->setFlow(QListView::LeftToRight);
        m_themeList->setResizeMode(QListView::Adjust);
        m_themeList->setViewMode(QListView::IconMode);

        verticalLayout_3->addWidget(m_themeList);

        m_buttonBox = new QDialogButtonBox(CompassConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(m_buttonBox);


        retranslateUi(CompassConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, CompassConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, CompassConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CompassConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *CompassConfigWidget)
    {
        CompassConfigWidget->setWindowTitle(QCoreApplication::translate("CompassConfigWidget", "Configure Compass Plugin", nullptr));
        label->setText(QCoreApplication::translate("CompassConfigWidget", "Theme", nullptr));

        const bool __sortingEnabled = m_themeList->isSortingEnabled();
        m_themeList->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = m_themeList->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("CompassConfigWidget", "Default", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = m_themeList->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("CompassConfigWidget", "Arrows", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = m_themeList->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("CompassConfigWidget", "Atom", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = m_themeList->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("CompassConfigWidget", "Magnet", nullptr));
        m_themeList->setSortingEnabled(__sortingEnabled);

    } // retranslateUi

};

namespace Ui {
    class CompassConfigWidget: public Ui_CompassConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMPASSCONFIGWIDGET_H
