/********************************************************************************
** Form generated from reading UI file 'MapScaleConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAPSCALECONFIGWIDGET_H
#define UI_MAPSCALECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_MapScaleConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *m_showRatioScaleCheckBox;
    QCheckBox *m_minimizeCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *MapScaleConfigWidget)
    {
        if (MapScaleConfigWidget->objectName().isEmpty())
            MapScaleConfigWidget->setObjectName("MapScaleConfigWidget");
        MapScaleConfigWidget->resize(328, 267);
        verticalLayout = new QVBoxLayout(MapScaleConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_showRatioScaleCheckBox = new QCheckBox(MapScaleConfigWidget);
        m_showRatioScaleCheckBox->setObjectName("m_showRatioScaleCheckBox");
        m_showRatioScaleCheckBox->setChecked(true);

        verticalLayout->addWidget(m_showRatioScaleCheckBox);

        m_minimizeCheckBox = new QCheckBox(MapScaleConfigWidget);
        m_minimizeCheckBox->setObjectName("m_minimizeCheckBox");

        verticalLayout->addWidget(m_minimizeCheckBox);

        verticalSpacer = new QSpacerItem(20, 164, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(MapScaleConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(MapScaleConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, MapScaleConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, MapScaleConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(MapScaleConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *MapScaleConfigWidget)
    {
        MapScaleConfigWidget->setWindowTitle(QCoreApplication::translate("MapScaleConfigWidget", "Configure Scale Bar Plugin", nullptr));
        m_showRatioScaleCheckBox->setText(QCoreApplication::translate("MapScaleConfigWidget", "Show Ratio Scale", nullptr));
        m_minimizeCheckBox->setText(QCoreApplication::translate("MapScaleConfigWidget", "Minimize", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MapScaleConfigWidget: public Ui_MapScaleConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAPSCALECONFIGWIDGET_H
