/********************************************************************************
** Form generated from reading UI file 'StarsConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STARSCONFIGWIDGET_H
#define UI_STARSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_StarsConfigWidget
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout;
    QSlider *m_magnitudeSlider;
    QSpinBox *spinBox;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_2;
    QListWidget *m_solarSystemListWidget;
    QCheckBox *m_viewSolarSystemLabelCheckbox;
    QCheckBox *m_zoomSunMoonCheckbox;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *m_viewDsosCheckbox;
    QSpacerItem *horizontalSpacer_7;
    QCheckBox *m_viewDsoLabelCheckbox;
    QPushButton *m_dsoLabelColorButton;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QCheckBox *m_viewConstellationLinesCheckbox;
    QPushButton *m_constellationColorButton;
    QSpacerItem *horizontalSpacer;
    QCheckBox *m_viewConstellationLabelsCheckbox;
    QPushButton *m_constellationLabelColorButton;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QLabel *label;
    QComboBox *constellationNamesComboBox;
    QSpacerItem *horizontalSpacer_8;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout_3;
    QCheckBox *m_viewCelestialEquatorCheckbox;
    QPushButton *m_celestialEquatorColorButton;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *m_viewCelestialPoleCheckbox;
    QPushButton *m_celestialPoleColorButton;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *m_viewEclipticCheckbox;
    QPushButton *m_eclipticColorButton;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_9;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *StarsConfigWidget)
    {
        if (StarsConfigWidget->objectName().isEmpty())
            StarsConfigWidget->setObjectName("StarsConfigWidget");
        StarsConfigWidget->resize(391, 488);
        gridLayout = new QGridLayout(StarsConfigWidget);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(StarsConfigWidget);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_4 = new QVBoxLayout(tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        groupBox_3 = new QGroupBox(tab);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout = new QHBoxLayout(groupBox_3);
        horizontalLayout->setObjectName("horizontalLayout");
        m_magnitudeSlider = new QSlider(groupBox_3);
        m_magnitudeSlider->setObjectName("m_magnitudeSlider");
        m_magnitudeSlider->setInputMethodHints(Qt::ImhNone);
        m_magnitudeSlider->setMaximum(7);
        m_magnitudeSlider->setValue(7);
        m_magnitudeSlider->setOrientation(Qt::Horizontal);
        m_magnitudeSlider->setTickPosition(QSlider::TicksBelow);
        m_magnitudeSlider->setTickInterval(1);

        horizontalLayout->addWidget(m_magnitudeSlider);

        spinBox = new QSpinBox(groupBox_3);
        spinBox->setObjectName("spinBox");
        spinBox->setValue(7);

        horizontalLayout->addWidget(spinBox);


        verticalLayout_4->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(tab);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_2 = new QVBoxLayout(groupBox_4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_solarSystemListWidget = new QListWidget(groupBox_4);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem1->setCheckState(Qt::Checked);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem2->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem3->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem4->setCheckState(Qt::Unchecked);
        __qlistwidgetitem4->setFlags(Qt::ItemIsSelectable|Qt::ItemIsDragEnabled|Qt::ItemIsUserCheckable);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem5->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem6->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem7->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem8->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem9 = new QListWidgetItem(m_solarSystemListWidget);
        __qlistwidgetitem9->setCheckState(Qt::Unchecked);
        m_solarSystemListWidget->setObjectName("m_solarSystemListWidget");

        verticalLayout_2->addWidget(m_solarSystemListWidget);

        m_viewSolarSystemLabelCheckbox = new QCheckBox(groupBox_4);
        m_viewSolarSystemLabelCheckbox->setObjectName("m_viewSolarSystemLabelCheckbox");
        m_viewSolarSystemLabelCheckbox->setChecked(true);

        verticalLayout_2->addWidget(m_viewSolarSystemLabelCheckbox);

        m_zoomSunMoonCheckbox = new QCheckBox(groupBox_4);
        m_zoomSunMoonCheckbox->setObjectName("m_zoomSunMoonCheckbox");
        m_zoomSunMoonCheckbox->setChecked(true);

        verticalLayout_2->addWidget(m_zoomSunMoonCheckbox);


        verticalLayout_4->addWidget(groupBox_4);

        groupBox = new QGroupBox(tab);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        m_viewDsosCheckbox = new QCheckBox(groupBox);
        m_viewDsosCheckbox->setObjectName("m_viewDsosCheckbox");
        m_viewDsosCheckbox->setChecked(true);

        gridLayout_2->addWidget(m_viewDsosCheckbox, 0, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(155, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_7, 0, 2, 1, 1);

        m_viewDsoLabelCheckbox = new QCheckBox(groupBox);
        m_viewDsoLabelCheckbox->setObjectName("m_viewDsoLabelCheckbox");
        m_viewDsoLabelCheckbox->setChecked(true);

        gridLayout_2->addWidget(m_viewDsoLabelCheckbox, 1, 0, 1, 1);

        m_dsoLabelColorButton = new QPushButton(groupBox);
        m_dsoLabelColorButton->setObjectName("m_dsoLabelColorButton");
        m_dsoLabelColorButton->setMinimumSize(QSize(30, 25));
        m_dsoLabelColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_2->addWidget(m_dsoLabelColorButton, 1, 1, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(155, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_6, 1, 2, 1, 1);


        verticalLayout_4->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout = new QVBoxLayout(tab_2);
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(tab_2);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setObjectName("gridLayout_4");
        m_viewConstellationLinesCheckbox = new QCheckBox(groupBox_2);
        m_viewConstellationLinesCheckbox->setObjectName("m_viewConstellationLinesCheckbox");
        m_viewConstellationLinesCheckbox->setChecked(true);

        gridLayout_4->addWidget(m_viewConstellationLinesCheckbox, 0, 0, 1, 1);

        m_constellationColorButton = new QPushButton(groupBox_2);
        m_constellationColorButton->setObjectName("m_constellationColorButton");
        m_constellationColorButton->setMinimumSize(QSize(30, 25));
        m_constellationColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_4->addWidget(m_constellationColorButton, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(152, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 3, 1, 2);

        m_viewConstellationLabelsCheckbox = new QCheckBox(groupBox_2);
        m_viewConstellationLabelsCheckbox->setObjectName("m_viewConstellationLabelsCheckbox");
        m_viewConstellationLabelsCheckbox->setChecked(true);

        gridLayout_4->addWidget(m_viewConstellationLabelsCheckbox, 1, 0, 1, 2);

        m_constellationLabelColorButton = new QPushButton(groupBox_2);
        m_constellationLabelColorButton->setObjectName("m_constellationLabelColorButton");
        m_constellationLabelColorButton->setMinimumSize(QSize(30, 25));
        m_constellationLabelColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_4->addWidget(m_constellationLabelColorButton, 1, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(152, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 1, 3, 1, 2);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_3, 2, 1, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout_4->addWidget(label, 3, 0, 1, 1);

        constellationNamesComboBox = new QComboBox(groupBox_2);
        constellationNamesComboBox->addItem(QString());
        constellationNamesComboBox->addItem(QString());
        constellationNamesComboBox->addItem(QString());
        constellationNamesComboBox->setObjectName("constellationNamesComboBox");

        gridLayout_4->addWidget(constellationNamesComboBox, 3, 1, 1, 3);

        horizontalSpacer_8 = new QSpacerItem(143, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_8, 3, 4, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        groupBox_5 = new QGroupBox(tab_2);
        groupBox_5->setObjectName("groupBox_5");
        gridLayout_3 = new QGridLayout(groupBox_5);
        gridLayout_3->setObjectName("gridLayout_3");
        m_viewCelestialEquatorCheckbox = new QCheckBox(groupBox_5);
        m_viewCelestialEquatorCheckbox->setObjectName("m_viewCelestialEquatorCheckbox");
        m_viewCelestialEquatorCheckbox->setChecked(true);

        gridLayout_3->addWidget(m_viewCelestialEquatorCheckbox, 0, 0, 1, 1);

        m_celestialEquatorColorButton = new QPushButton(groupBox_5);
        m_celestialEquatorColorButton->setObjectName("m_celestialEquatorColorButton");
        m_celestialEquatorColorButton->setMinimumSize(QSize(30, 25));
        m_celestialEquatorColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_3->addWidget(m_celestialEquatorColorButton, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(210, 22, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        m_viewCelestialPoleCheckbox = new QCheckBox(groupBox_5);
        m_viewCelestialPoleCheckbox->setObjectName("m_viewCelestialPoleCheckbox");
        m_viewCelestialPoleCheckbox->setChecked(true);

        gridLayout_3->addWidget(m_viewCelestialPoleCheckbox, 1, 0, 1, 1);

        m_celestialPoleColorButton = new QPushButton(groupBox_5);
        m_celestialPoleColorButton->setObjectName("m_celestialPoleColorButton");
        m_celestialPoleColorButton->setMinimumSize(QSize(30, 25));
        m_celestialPoleColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_3->addWidget(m_celestialPoleColorButton, 1, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(152, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 1, 2, 1, 1);

        m_viewEclipticCheckbox = new QCheckBox(groupBox_5);
        m_viewEclipticCheckbox->setObjectName("m_viewEclipticCheckbox");
        m_viewEclipticCheckbox->setChecked(true);

        gridLayout_3->addWidget(m_viewEclipticCheckbox, 2, 0, 1, 1);

        m_eclipticColorButton = new QPushButton(groupBox_5);
        m_eclipticColorButton->setObjectName("m_eclipticColorButton");
        m_eclipticColorButton->setMinimumSize(QSize(30, 25));
        m_eclipticColorButton->setMaximumSize(QSize(30, 25));

        gridLayout_3->addWidget(m_eclipticColorButton, 2, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(184, 22, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_5, 2, 2, 1, 1);


        verticalLayout->addWidget(groupBox_5);

        verticalSpacer_2 = new QSpacerItem(20, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        tabWidget->addTab(tab_2, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_9);

        m_buttonBox = new QDialogButtonBox(StarsConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_2->addWidget(m_buttonBox);


        gridLayout->addLayout(horizontalLayout_2, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(constellationNamesComboBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(StarsConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, StarsConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, StarsConfigWidget, qOverload<>(&QDialog::reject));
        QObject::connect(m_magnitudeSlider, &QSlider::valueChanged, spinBox, &QSpinBox::setValue);
        QObject::connect(spinBox, &QSpinBox::valueChanged, m_magnitudeSlider, &QSlider::setValue);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(StarsConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *StarsConfigWidget)
    {
        StarsConfigWidget->setWindowTitle(QCoreApplication::translate("StarsConfigWidget", "Configure Stars Plugin", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("StarsConfigWidget", "Star Magnitude Limit", nullptr));
        spinBox->setSuffix(QCoreApplication::translate("StarsConfigWidget", " mag", nullptr));
        spinBox->setPrefix(QString());
        groupBox_4->setTitle(QCoreApplication::translate("StarsConfigWidget", "Solar System", nullptr));

        const bool __sortingEnabled = m_solarSystemListWidget->isSortingEnabled();
        m_solarSystemListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = m_solarSystemListWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("StarsConfigWidget", "Sun", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = m_solarSystemListWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("StarsConfigWidget", "Moon", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = m_solarSystemListWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("StarsConfigWidget", "Mercury", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = m_solarSystemListWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("StarsConfigWidget", "Venus", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = m_solarSystemListWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("StarsConfigWidget", "Earth", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = m_solarSystemListWidget->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("StarsConfigWidget", "Mars", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = m_solarSystemListWidget->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("StarsConfigWidget", "Jupiter", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = m_solarSystemListWidget->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("StarsConfigWidget", "Saturn", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = m_solarSystemListWidget->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("StarsConfigWidget", "Uranus", nullptr));
        QListWidgetItem *___qlistwidgetitem9 = m_solarSystemListWidget->item(9);
        ___qlistwidgetitem9->setText(QCoreApplication::translate("StarsConfigWidget", "Neptune", nullptr));
        m_solarSystemListWidget->setSortingEnabled(__sortingEnabled);

        m_viewSolarSystemLabelCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Use name labels", nullptr));
        m_zoomSunMoonCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Magnify Sun and Moon", nullptr));
        groupBox->setTitle(QCoreApplication::translate("StarsConfigWidget", "Other", nullptr));
        m_viewDsosCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Deep Sky Objects", nullptr));
        m_viewDsoLabelCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Deep Sky Object Labels", nullptr));
        m_dsoLabelColorButton->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("StarsConfigWidget", "Celestial Objects", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("StarsConfigWidget", "Constellations", nullptr));
        m_viewConstellationLinesCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Lines", nullptr));
        m_constellationColorButton->setText(QString());
        m_viewConstellationLabelsCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Labels", nullptr));
        m_constellationLabelColorButton->setText(QString());
        label->setText(QCoreApplication::translate("StarsConfigWidget", "Names", nullptr));
        constellationNamesComboBox->setItemText(0, QCoreApplication::translate("StarsConfigWidget", "Latin Name", nullptr));
        constellationNamesComboBox->setItemText(1, QCoreApplication::translate("StarsConfigWidget", "Native Translation", nullptr));
        constellationNamesComboBox->setItemText(2, QCoreApplication::translate("StarsConfigWidget", "Abbreviation", nullptr));

        groupBox_5->setTitle(QCoreApplication::translate("StarsConfigWidget", "Coordinate Grid", nullptr));
        m_viewCelestialEquatorCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Celestial Equator", nullptr));
        m_celestialEquatorColorButton->setText(QString());
        m_viewCelestialPoleCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Celestial Poles", nullptr));
        m_celestialPoleColorButton->setText(QString());
        m_viewEclipticCheckbox->setText(QCoreApplication::translate("StarsConfigWidget", "Ecliptic", nullptr));
        m_eclipticColorButton->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("StarsConfigWidget", "Lines and Orientation", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StarsConfigWidget: public Ui_StarsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STARSCONFIGWIDGET_H
