/********************************************************************************
** Form generated from reading UI file 'NewBookmarkFolderDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWBOOKMARKFOLDERDIALOG_H
#define UI_NEWBOOKMARKFOLDERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_UiNewBookmarkFolderDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *m_namelbl;
    QLineEdit *m_name;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiNewBookmarkFolderDialog)
    {
        if (UiNewBookmarkFolderDialog->objectName().isEmpty())
            UiNewBookmarkFolderDialog->setObjectName("UiNewBookmarkFolderDialog");
        UiNewBookmarkFolderDialog->resize(302, 67);
        verticalLayout = new QVBoxLayout(UiNewBookmarkFolderDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_namelbl = new QLabel(UiNewBookmarkFolderDialog);
        m_namelbl->setObjectName("m_namelbl");

        horizontalLayout_2->addWidget(m_namelbl);

        m_name = new QLineEdit(UiNewBookmarkFolderDialog);
        m_name->setObjectName("m_name");

        horizontalLayout_2->addWidget(m_name);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(UiNewBookmarkFolderDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        m_namelbl->setBuddy(m_name);
#endif // QT_CONFIG(shortcut)

        retranslateUi(UiNewBookmarkFolderDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, UiNewBookmarkFolderDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiNewBookmarkFolderDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UiNewBookmarkFolderDialog);
    } // setupUi

    void retranslateUi(QDialog *UiNewBookmarkFolderDialog)
    {
        UiNewBookmarkFolderDialog->setWindowTitle(QCoreApplication::translate("UiNewBookmarkFolderDialog", "New Bookmark Folder", nullptr));
        m_namelbl->setText(QCoreApplication::translate("UiNewBookmarkFolderDialog", "&Folder name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiNewBookmarkFolderDialog: public Ui_UiNewBookmarkFolderDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWBOOKMARKFOLDERDIALOG_H
