/****************************************************************************
** Meta object code from reading C++ file 'marble_part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/apps/marble-kde/marble_part.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'marble_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10MarblePartE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarblePart::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10MarblePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarblePart",
        "openUrl",
        "",
        "QUrl",
        "url",
        "openFile",
        "showPosition",
        "position",
        "showZoomLevel",
        "showDateTime",
        "mapThemeChanged",
        "newMapTheme",
        "createPluginMenus",
        "createFolderList",
        "fallBackToDefaultTheme",
        "exportMapScreenShot",
        "printMapScreenShot",
        "copyMap",
        "copyCoordinates",
        "setShowClouds",
        "setShowBookmarks",
        "isChecked",
        "showFullScreen",
        "showStatusBar",
        "changeRecordingState",
        "showDateTimeLabel",
        "showPositionLabel",
        "showAltitudeLabel",
        "showTileZoomLevelLabel",
        "showDownloadProgressBar",
        "handleProgress",
        "active",
        "queued",
        "removeProgressItem",
        "lockFloatItemPosition",
        "controlSun",
        "controlTime",
        "showSun",
        "lockToSubSolarPoint",
        "setSubSolarPointIconVisible",
        "workOffline",
        "setupStatusBar",
        "showNewStuffDialog",
        "showDownloadRegionDialog",
        "downloadRegion",
        "showStatusBarContextMenu",
        "QPoint",
        "pos",
        "showMapWizard",
        "editSettings",
        "enableApplyButton",
        "applyPluginState",
        "updateSettings",
        "updateStatusBar",
        "updateCloudSyncStatus",
        "status",
        "writePluginSettings",
        "readPluginSettings",
        "openEditBookmarkDialog",
        "setHome",
        "openManageBookmarksDialog",
        "createBookmarksListMenu",
        "QMenu*",
        "GeoDataFolder",
        "lookAtBookmark",
        "QAction*",
        "updateMapEditButtonVisibility",
        "mapTheme",
        "showMovieCaptureDialog",
        "stopRecording",
        "updateCloudSyncCredentials"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openUrl'
        QtMocHelpers::SlotData<bool(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<bool()>(5, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'showPosition'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'showZoomLevel'
        QtMocHelpers::SlotData<void(const int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'showDateTime'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mapThemeChanged'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'createPluginMenus'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createFolderList'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fallBackToDefaultTheme'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exportMapScreenShot'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printMapScreenShot'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyMap'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyCoordinates'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setShowClouds'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setShowBookmarks'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showFullScreen'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showStatusBar'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'changeRecordingState'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDateTimeLabel'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showPositionLabel'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showAltitudeLabel'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showTileZoomLevelLabel'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'showDownloadProgressBar'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'handleProgress'
        QtMocHelpers::SlotData<void(int, int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'removeProgressItem'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lockFloatItemPosition'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'controlSun'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'controlTime'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSun'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'lockToSubSolarPoint'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setSubSolarPointIconVisible'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'workOffline'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setupStatusBar'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showNewStuffDialog'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDownloadRegionDialog'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadRegion'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showStatusBarContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'showMapWizard'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSettings'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableApplyButton'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyPluginState'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSettings'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCloudSyncStatus'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 55 },
        }}),
        // Slot 'writePluginSettings'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readPluginSettings'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openEditBookmarkDialog'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setHome'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openManageBookmarksDialog'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createBookmarksListMenu'
        QtMocHelpers::SlotData<void(QMenu *, const GeoDataFolder &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 62, 2 }, { 0x80000000 | 63, 2 },
        }}),
        // Slot 'lookAtBookmark'
        QtMocHelpers::SlotData<void(QAction *)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 65, 2 },
        }}),
        // Slot 'updateMapEditButtonVisibility'
        QtMocHelpers::SlotData<void(const QString &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 67 },
        }}),
        // Slot 'showMovieCaptureDialog'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopRecording'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCloudSyncCredentials'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarblePart, qt_meta_tag_ZN6Marble10MarblePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MarblePart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadOnlyPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MarblePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MarblePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10MarblePartE_t>.metaTypes,
    nullptr
} };

void Marble::MarblePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarblePart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->openFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->showPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->showZoomLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->showDateTime(); break;
        case 5: _t->mapThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->createPluginMenus(); break;
        case 7: _t->createFolderList(); break;
        case 8: _t->fallBackToDefaultTheme(); break;
        case 9: _t->exportMapScreenShot(); break;
        case 10: _t->printMapScreenShot(); break;
        case 11: _t->copyMap(); break;
        case 12: _t->copyCoordinates(); break;
        case 13: _t->setShowClouds((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setShowBookmarks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->showStatusBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->changeRecordingState(); break;
        case 18: _t->showDateTimeLabel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->showPositionLabel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->showAltitudeLabel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->showTileZoomLevelLabel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->showDownloadProgressBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->handleProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->removeProgressItem(); break;
        case 25: _t->lockFloatItemPosition((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->controlSun(); break;
        case 27: _t->controlTime(); break;
        case 28: _t->showSun((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->lockToSubSolarPoint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setSubSolarPointIconVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->workOffline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setupStatusBar(); break;
        case 33: _t->showNewStuffDialog(); break;
        case 34: _t->showDownloadRegionDialog(); break;
        case 35: _t->downloadRegion(); break;
        case 36: _t->showStatusBarContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 37: _t->showMapWizard(); break;
        case 38: _t->editSettings(); break;
        case 39: _t->enableApplyButton(); break;
        case 40: _t->applyPluginState(); break;
        case 41: _t->updateSettings(); break;
        case 42: _t->updateStatusBar(); break;
        case 43: _t->updateCloudSyncStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->writePluginSettings(); break;
        case 45: _t->readPluginSettings(); break;
        case 46: _t->openEditBookmarkDialog(); break;
        case 47: _t->setHome(); break;
        case 48: _t->openManageBookmarksDialog(); break;
        case 49: _t->createBookmarksListMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFolder>>(_a[2]))); break;
        case 50: _t->lookAtBookmark((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 51: _t->updateMapEditButtonVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 52: _t->showMovieCaptureDialog(); break;
        case 53: _t->stopRecording(); break;
        case 54: _t->updateCloudSyncCredentials(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Marble::MarblePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarblePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10MarblePartE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int Marble::MarblePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    return _id;
}
QT_WARNING_POP
