/********************************************************************************
** Form generated from reading UI file 'TourCaptureDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOURCAPTUREDIALOG_H
#define UI_TOURCAPTUREDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TourCaptureDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QHBoxLayout *horisontalLayout;
    QLineEdit *destinationEdit;
    QPushButton *openButton;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QSpinBox *fpsSpin;
    QSlider *fpsSlider;
    QProgressBar *progressBar;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *rate;
    QSpacerItem *horizontalSpacer;
    QPushButton *startButton;
    QPushButton *closeButton;

    void setupUi(QDialog *TourCaptureDialog)
    {
        if (TourCaptureDialog->objectName().isEmpty())
            TourCaptureDialog->setObjectName("TourCaptureDialog");
        TourCaptureDialog->resize(364, 207);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TourCaptureDialog->sizePolicy().hasHeightForWidth());
        TourCaptureDialog->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(TourCaptureDialog);
        verticalLayout_2->setSpacing(5);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(5, 5, 5, 5);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(5);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(5, 5, 5, 5);
        label = new QLabel(TourCaptureDialog);
        label->setObjectName("label");
        QFont font;
        font.setPointSize(9);
        font.setBold(false);
        label->setFont(font);

        verticalLayout->addWidget(label);

        horisontalLayout = new QHBoxLayout();
        horisontalLayout->setObjectName("horisontalLayout");
        destinationEdit = new QLineEdit(TourCaptureDialog);
        destinationEdit->setObjectName("destinationEdit");
        destinationEdit->setReadOnly(true);

        horisontalLayout->addWidget(destinationEdit);

        openButton = new QPushButton(TourCaptureDialog);
        openButton->setObjectName("openButton");

        horisontalLayout->addWidget(openButton);


        verticalLayout->addLayout(horisontalLayout);

        groupBox = new QGroupBox(TourCaptureDialog);
        groupBox->setObjectName("groupBox");
        groupBox->setFont(font);
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setSpacing(5);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(5, 5, 5, 5);
        fpsSpin = new QSpinBox(groupBox);
        fpsSpin->setObjectName("fpsSpin");
        fpsSpin->setMinimum(1);
        fpsSpin->setMaximum(60);
        fpsSpin->setValue(30);

        verticalLayout_3->addWidget(fpsSpin);

        fpsSlider = new QSlider(groupBox);
        fpsSlider->setObjectName("fpsSlider");
        fpsSlider->setMinimum(1);
        fpsSlider->setMaximum(60);
        fpsSlider->setValue(30);
        fpsSlider->setOrientation(Qt::Horizontal);

        verticalLayout_3->addWidget(fpsSlider);

        progressBar = new QProgressBar(groupBox);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(24);

        verticalLayout_3->addWidget(progressBar);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetDefaultConstraint);

        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        rate = new QLabel(groupBox);
        rate->setObjectName("rate");
        rate->setMinimumSize(QSize(120, 0));

        horizontalLayout_2->addWidget(rate);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        startButton = new QPushButton(groupBox);
        startButton->setObjectName("startButton");

        horizontalLayout_2->addWidget(startButton);

        closeButton = new QPushButton(groupBox);
        closeButton->setObjectName("closeButton");

        horizontalLayout_2->addWidget(closeButton);


        verticalLayout_3->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox);


        verticalLayout_2->addLayout(verticalLayout);

        QWidget::setTabOrder(openButton, destinationEdit);

        retranslateUi(TourCaptureDialog);

        QMetaObject::connectSlotsByName(TourCaptureDialog);
    } // setupUi

    void retranslateUi(QDialog *TourCaptureDialog)
    {
        TourCaptureDialog->setWindowTitle(QCoreApplication::translate("TourCaptureDialog", "Movie Recording", nullptr));
        label->setText(QCoreApplication::translate("TourCaptureDialog", "Destination video", nullptr));
        openButton->setText(QCoreApplication::translate("TourCaptureDialog", "Open\342\200\246", nullptr));
        groupBox->setTitle(QCoreApplication::translate("TourCaptureDialog", "FPS (frames per second)", nullptr));
        rate->setText(QString());
        startButton->setText(QCoreApplication::translate("TourCaptureDialog", "Start", nullptr));
        closeButton->setText(QCoreApplication::translate("TourCaptureDialog", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TourCaptureDialog: public Ui_TourCaptureDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOURCAPTUREDIALOG_H
