/********************************************************************************
** Form generated from reading UI file 'ElevationProfileConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ELEVATIONPROFILECONFIGWIDGET_H
#define UI_ELEVATIONPROFILECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ElevationProfileConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *m_zoomToViewportCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *ElevationProfileConfigWidget)
    {
        if (ElevationProfileConfigWidget->objectName().isEmpty())
            ElevationProfileConfigWidget->setObjectName("ElevationProfileConfigWidget");
        ElevationProfileConfigWidget->resize(328, 267);
        verticalLayout = new QVBoxLayout(ElevationProfileConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_zoomToViewportCheckBox = new QCheckBox(ElevationProfileConfigWidget);
        m_zoomToViewportCheckBox->setObjectName("m_zoomToViewportCheckBox");
        m_zoomToViewportCheckBox->setChecked(false);

        verticalLayout->addWidget(m_zoomToViewportCheckBox);

        verticalSpacer = new QSpacerItem(20, 164, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_buttonBox = new QDialogButtonBox(ElevationProfileConfigWidget);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(ElevationProfileConfigWidget);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, ElevationProfileConfigWidget, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, ElevationProfileConfigWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ElevationProfileConfigWidget);
    } // setupUi

    void retranslateUi(QDialog *ElevationProfileConfigWidget)
    {
        ElevationProfileConfigWidget->setWindowTitle(QCoreApplication::translate("ElevationProfileConfigWidget", "Configure Elevation Profile Plugin", nullptr));
        m_zoomToViewportCheckBox->setText(QCoreApplication::translate("ElevationProfileConfigWidget", "Zoom to viewport", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ElevationProfileConfigWidget: public Ui_ElevationProfileConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ELEVATIONPROFILECONFIGWIDGET_H
