/********************************************************************************
** Form generated from reading UI file 'GpsInfoPlugin.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GPSINFOPLUGIN_H
#define UI_GPSINFOPLUGIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_GpsInfoPlugin
{
public:
    QFormLayout *formLayout;
    QLabel *Speed;
    QLabel *SpeedValue;
    QLabel *Direction;
    QLabel *DirectionValue;
    QLabel *Altitude;
    QLabel *AltitudeValue;
    QLabel *Precision;
    QLabel *PrecisionValue;

    void setupUi(QWidget *GpsInfoPlugin)
    {
        if (GpsInfoPlugin->objectName().isEmpty())
            GpsInfoPlugin->setObjectName("GpsInfoPlugin");
        GpsInfoPlugin->setEnabled(true);
        GpsInfoPlugin->resize(85, 80);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GpsInfoPlugin->sizePolicy().hasHeightForWidth());
        GpsInfoPlugin->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(GpsInfoPlugin);
        formLayout->setContentsMargins(2, 2, 2, 2);
        formLayout->setObjectName("formLayout");
        Speed = new QLabel(GpsInfoPlugin);
        Speed->setObjectName("Speed");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, Speed);

        SpeedValue = new QLabel(GpsInfoPlugin);
        SpeedValue->setObjectName("SpeedValue");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, SpeedValue);

        Direction = new QLabel(GpsInfoPlugin);
        Direction->setObjectName("Direction");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, Direction);

        DirectionValue = new QLabel(GpsInfoPlugin);
        DirectionValue->setObjectName("DirectionValue");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, DirectionValue);

        Altitude = new QLabel(GpsInfoPlugin);
        Altitude->setObjectName("Altitude");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, Altitude);

        AltitudeValue = new QLabel(GpsInfoPlugin);
        AltitudeValue->setObjectName("AltitudeValue");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, AltitudeValue);

        Precision = new QLabel(GpsInfoPlugin);
        Precision->setObjectName("Precision");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, Precision);

        PrecisionValue = new QLabel(GpsInfoPlugin);
        PrecisionValue->setObjectName("PrecisionValue");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, PrecisionValue);


        retranslateUi(GpsInfoPlugin);

        QMetaObject::connectSlotsByName(GpsInfoPlugin);
    } // setupUi

    void retranslateUi(QWidget *GpsInfoPlugin)
    {
        Speed->setText(QCoreApplication::translate("GpsInfoPlugin", "Speed", nullptr));
        SpeedValue->setText(QString());
        Direction->setText(QCoreApplication::translate("GpsInfoPlugin", "Direction", nullptr));
        DirectionValue->setText(QString());
        Altitude->setText(QCoreApplication::translate("GpsInfoPlugin", "Altitude", nullptr));
        AltitudeValue->setText(QString());
        Precision->setText(QCoreApplication::translate("GpsInfoPlugin", "Precision", nullptr));
        PrecisionValue->setText(QString());
        (void)GpsInfoPlugin;
    } // retranslateUi

};

namespace Ui {
    class GpsInfoPlugin: public Ui_GpsInfoPlugin {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GPSINFOPLUGIN_H
