/****************************************************************************
** Meta object code from reading C++ file 'OwsServiceManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/OwsServiceManager.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OwsServiceManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble17OwsServiceManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::OwsServiceManager::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::OwsServiceManager",
        "wmsCapabilitiesReady",
        "",
        "wmtsCapabilitiesReady",
        "imageRequestResultReady",
        "queryOwsCapabilities",
        "QUrl",
        "queryUrl",
        "serviceString",
        "queryWmsMap",
        "url",
        "layers",
        "projection",
        "bbox",
        "format",
        "styles",
        "queryWmsLevelZeroTile",
        "queryWmsPreviewImage",
        "queryWmsLegendImage",
        "queryWmtsLevelZeroTile",
        "style",
        "tileMatrixSet",
        "queryWmtsPreviewImage",
        "queryWmtsTile",
        "tileMatrix",
        "tileRow",
        "tileCol",
        "queryXYZPreviewImage",
        "urlString",
        "queryXYZLevelZeroTile",
        "queryXYZImage",
        "handleAuthentication",
        "QNetworkReply*",
        "reply",
        "QAuthenticator*",
        "authenticator",
        "setCapabilitiesStatus",
        "OwsCapabilitiesStatus",
        "capabilitiesStatus",
        "owsServiceType",
        "OwsServiceType",
        "wmsCapabilities",
        "WmsCapabilities",
        "wmtsCapabilities",
        "WmtsCapabilities",
        "imageRequestResult",
        "ImageRequestResult",
        "resultImage",
        "QImage",
        "resultRaw",
        "resultFormat",
        "resultType",
        "ImageResultType",
        "parseOwsCapabilities",
        "parseWmsCapabilities",
        "parseWmtsCapabilities",
        "parseImageResult"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wmsCapabilitiesReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wmtsCapabilitiesReady'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageRequestResultReady'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'queryOwsCapabilities'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'queryOwsCapabilities'
        QtMocHelpers::SlotData<void(const QUrl &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'queryWmsMap'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &, const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'queryWmsMap'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &, const QString &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
            { QMetaType::QString, 14 },
        }}),
        // Slot 'queryWmsLevelZeroTile'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 14 },
            { QMetaType::QString, 15 },
        }}),
        // Slot 'queryWmsLevelZeroTile'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'queryWmsPreviewImage'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 14 },
            { QMetaType::QString, 15 },
        }}),
        // Slot 'queryWmsPreviewImage'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QString &, const QString &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'queryWmsLegendImage'
        QtMocHelpers::SlotData<void(const QUrl &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 },
        }}),
        // Slot 'queryWmtsLevelZeroTile'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'queryWmtsPreviewImage'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'queryWmtsTile'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::QString, 24 },
            { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'queryXYZPreviewImage'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'queryXYZLevelZeroTile'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'queryXYZImage'
        QtMocHelpers::SlotData<void(const QString)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'handleAuthentication'
        QtMocHelpers::SlotData<void(QNetworkReply *, QAuthenticator *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'setCapabilitiesStatus'
        QtMocHelpers::SlotData<void(OwsCapabilitiesStatus)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'capabilitiesStatus'
        QtMocHelpers::SlotData<OwsCapabilitiesStatus() const>(38, 2, QMC::AccessPublic, 0x80000000 | 37),
        // Slot 'owsServiceType'
        QtMocHelpers::SlotData<OwsServiceType()>(39, 2, QMC::AccessPublic, 0x80000000 | 40),
        // Slot 'wmsCapabilities'
        QtMocHelpers::SlotData<WmsCapabilities()>(41, 2, QMC::AccessPublic, 0x80000000 | 42),
        // Slot 'wmtsCapabilities'
        QtMocHelpers::SlotData<WmtsCapabilities()>(43, 2, QMC::AccessPublic, 0x80000000 | 44),
        // Slot 'imageRequestResult'
        QtMocHelpers::SlotData<ImageRequestResult()>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'resultImage'
        QtMocHelpers::SlotData<QImage()>(47, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'resultRaw'
        QtMocHelpers::SlotData<QByteArray()>(49, 2, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'resultFormat'
        QtMocHelpers::SlotData<QString()>(50, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'resultType'
        QtMocHelpers::SlotData<ImageResultType()>(51, 2, QMC::AccessPublic, 0x80000000 | 52),
        // Slot 'parseOwsCapabilities'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'parseWmsCapabilities'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'parseWmtsCapabilities'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'parseImageResult'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OwsServiceManager, qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::OwsServiceManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>.metaTypes,
    nullptr
} };

void Marble::OwsServiceManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OwsServiceManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wmsCapabilitiesReady(); break;
        case 1: _t->wmtsCapabilitiesReady(); break;
        case 2: _t->imageRequestResultReady(); break;
        case 3: _t->queryOwsCapabilities((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->queryOwsCapabilities((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->queryWmsMap((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 6: _t->queryWmsMap((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 7: _t->queryWmsLevelZeroTile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 8: _t->queryWmsLevelZeroTile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 9: _t->queryWmsPreviewImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 10: _t->queryWmsPreviewImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 11: _t->queryWmsLegendImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->queryWmtsLevelZeroTile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: _t->queryWmtsPreviewImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->queryWmtsTile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 15: _t->queryXYZPreviewImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->queryXYZLevelZeroTile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->queryXYZImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->handleAuthentication((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 19: _t->setCapabilitiesStatus((*reinterpret_cast<std::add_pointer_t<OwsCapabilitiesStatus>>(_a[1]))); break;
        case 20: { OwsCapabilitiesStatus _r = _t->capabilitiesStatus();
            if (_a[0]) *reinterpret_cast<OwsCapabilitiesStatus*>(_a[0]) = std::move(_r); }  break;
        case 21: { OwsServiceType _r = _t->owsServiceType();
            if (_a[0]) *reinterpret_cast<OwsServiceType*>(_a[0]) = std::move(_r); }  break;
        case 22: { WmsCapabilities _r = _t->wmsCapabilities();
            if (_a[0]) *reinterpret_cast<WmsCapabilities*>(_a[0]) = std::move(_r); }  break;
        case 23: { WmtsCapabilities _r = _t->wmtsCapabilities();
            if (_a[0]) *reinterpret_cast<WmtsCapabilities*>(_a[0]) = std::move(_r); }  break;
        case 24: { ImageRequestResult _r = _t->imageRequestResult();
            if (_a[0]) *reinterpret_cast<ImageRequestResult*>(_a[0]) = std::move(_r); }  break;
        case 25: { QImage _r = _t->resultImage();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 26: { QByteArray _r = _t->resultRaw();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 27: { QString _r = _t->resultFormat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { ImageResultType _r = _t->resultType();
            if (_a[0]) *reinterpret_cast<ImageResultType*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->parseOwsCapabilities((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 30: _t->parseWmsCapabilities((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 31: _t->parseWmtsCapabilities((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 32: _t->parseImageResult((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OwsServiceManager::*)()>(_a, &OwsServiceManager::wmsCapabilitiesReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwsServiceManager::*)()>(_a, &OwsServiceManager::wmtsCapabilitiesReady, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OwsServiceManager::*)()>(_a, &OwsServiceManager::imageRequestResultReady, 2))
            return;
    }
}

const QMetaObject *Marble::OwsServiceManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::OwsServiceManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17OwsServiceManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::OwsServiceManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void Marble::OwsServiceManager::wmsCapabilitiesReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::OwsServiceManager::wmtsCapabilitiesReady()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::OwsServiceManager::imageRequestResultReady()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
