/****************************************************************************
** Meta object code from reading C++ file 'Navigation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/lib/marble/declarative/Navigation.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Navigation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble10NavigationE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::Navigation::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble10NavigationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::Navigation",
        "QML.Element",
        "auto",
        "mapChanged",
        "",
        "guidanceModeEnabledChanged",
        "mutedChanged",
        "arg",
        "nextInstructionTextChanged",
        "nextInstructionImageChanged",
        "nextInstructionDistanceChanged",
        "destinationDistanceChanged",
        "nextRoadChanged",
        "voiceNavigationAnnouncementChanged",
        "soundEnabledChanged",
        "speakerChanged",
        "deviationChanged",
        "marbleQuickItemChanged",
        "Marble::MarbleQuickItem*",
        "marbleQuickItem",
        "screenAccuracyChanged",
        "screenPositionChanged",
        "setMarbleQuickItem",
        "update",
        "updateScreenPosition",
        "guidanceModeEnabled",
        "muted",
        "speaker",
        "nextInstructionText",
        "nextRoad",
        "nextInstructionImage",
        "nextInstructionDistance",
        "destinationDistance",
        "voiceNavigationAnnouncement",
        "deviated",
        "screenAccuracy",
        "screenPosition",
        "QPointF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mapChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guidanceModeEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'nextInstructionTextChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextInstructionImageChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextInstructionDistanceChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'destinationDistanceChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextRoadChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'voiceNavigationAnnouncementChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'soundEnabledChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speakerChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviationChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marbleQuickItemChanged'
        QtMocHelpers::SignalData<void(Marble::MarbleQuickItem *)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'screenAccuracyChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenPositionChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMarbleQuickItem'
        QtMocHelpers::SlotData<void(Marble::MarbleQuickItem *)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateScreenPosition'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'marbleQuickItem'
        QtMocHelpers::PropertyData<Marble::MarbleQuickItem*>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'guidanceModeEnabled'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'muted'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'speaker'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'nextInstructionText'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'nextRoad'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'nextInstructionImage'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'nextInstructionDistance'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags, 5),
        // property 'destinationDistance'
        QtMocHelpers::PropertyData<qreal>(32, QMetaType::QReal, QMC::DefaultPropertyFlags, 6),
        // property 'voiceNavigationAnnouncement'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'deviated'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'screenAccuracy'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags, 13),
        // property 'screenPosition'
        QtMocHelpers::PropertyData<QPointF>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Navigation, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::Navigation::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10NavigationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10NavigationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble10NavigationE_t>.metaTypes,
    nullptr
} };

void Marble::Navigation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Navigation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mapChanged(); break;
        case 1: _t->guidanceModeEnabledChanged(); break;
        case 2: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->nextInstructionTextChanged(); break;
        case 4: _t->nextInstructionImageChanged(); break;
        case 5: _t->nextInstructionDistanceChanged(); break;
        case 6: _t->destinationDistanceChanged(); break;
        case 7: _t->nextRoadChanged(); break;
        case 8: _t->voiceNavigationAnnouncementChanged(); break;
        case 9: _t->soundEnabledChanged(); break;
        case 10: _t->speakerChanged(); break;
        case 11: _t->deviationChanged(); break;
        case 12: _t->marbleQuickItemChanged((*reinterpret_cast<std::add_pointer_t<Marble::MarbleQuickItem*>>(_a[1]))); break;
        case 13: _t->screenAccuracyChanged(); break;
        case 14: _t->screenPositionChanged(); break;
        case 15: _t->setMarbleQuickItem((*reinterpret_cast<std::add_pointer_t<Marble::MarbleQuickItem*>>(_a[1]))); break;
        case 16: _t->update(); break;
        case 17: _t->updateScreenPosition(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::mapChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::guidanceModeEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(bool )>(_a, &Navigation::mutedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::nextInstructionTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::nextInstructionImageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::nextInstructionDistanceChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::destinationDistanceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::nextRoadChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::voiceNavigationAnnouncementChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::soundEnabledChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::speakerChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::deviationChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(Marble::MarbleQuickItem * )>(_a, &Navigation::marbleQuickItemChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::screenAccuracyChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)()>(_a, &Navigation::screenPositionChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Marble::MarbleQuickItem**>(_v) = _t->marbleQuickItem(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->guidanceModeEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->muted(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->speaker(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->nextInstructionText(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->nextRoad(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->nextInstructionImage(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->nextInstructionDistance(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->destinationDistance(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->voiceNavigationAnnouncement(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->deviated(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->screenAccuracy(); break;
        case 12: *reinterpret_cast<QPointF*>(_v) = _t->screenPosition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMarbleQuickItem(*reinterpret_cast<Marble::MarbleQuickItem**>(_v)); break;
        case 1: _t->setGuidanceModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setMuted(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setSpeaker(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::Navigation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::Navigation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble10NavigationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::Navigation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Marble::Navigation::mapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::Navigation::guidanceModeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::Navigation::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::Navigation::nextInstructionTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::Navigation::nextInstructionImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::Navigation::nextInstructionDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::Navigation::destinationDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Marble::Navigation::nextRoadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Marble::Navigation::voiceNavigationAnnouncementChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Marble::Navigation::soundEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Marble::Navigation::speakerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Marble::Navigation::deviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Marble::Navigation::marbleQuickItemChanged(Marble::MarbleQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Marble::Navigation::screenAccuracyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Marble::Navigation::screenPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
