/********************************************************************************
** Form generated from reading UI file 'ElevationWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ELEVATIONWIDGET_H
#define UI_ELEVATIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ElevationWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *elevationLabel;
    QDoubleSpinBox *elevationSpinBox;
    QLabel *elevationModeLabel;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ElevationWidget)
    {
        if (ElevationWidget->objectName().isEmpty())
            ElevationWidget->setObjectName("ElevationWidget");
        ElevationWidget->resize(319, 114);
        verticalLayout = new QVBoxLayout(ElevationWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        elevationLabel = new QLabel(ElevationWidget);
        elevationLabel->setObjectName("elevationLabel");

        horizontalLayout->addWidget(elevationLabel);

        elevationSpinBox = new QDoubleSpinBox(ElevationWidget);
        elevationSpinBox->setObjectName("elevationSpinBox");
        elevationSpinBox->setMaximum(1000000.000000000000000);

        horizontalLayout->addWidget(elevationSpinBox);

        elevationModeLabel = new QLabel(ElevationWidget);
        elevationModeLabel->setObjectName("elevationModeLabel");

        horizontalLayout->addWidget(elevationModeLabel);

        horizontalSpacer = new QSpacerItem(29, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 72, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ElevationWidget);

        QMetaObject::connectSlotsByName(ElevationWidget);
    } // setupUi

    void retranslateUi(QWidget *ElevationWidget)
    {
        elevationLabel->setText(QCoreApplication::translate("ElevationWidget", "Elevation:", nullptr));
        elevationSpinBox->setSuffix(QCoreApplication::translate("ElevationWidget", " m", nullptr));
        elevationModeLabel->setText(QCoreApplication::translate("ElevationWidget", "above sea level", nullptr));
        (void)ElevationWidget;
    } // retranslateUi

};

namespace Ui {
    class ElevationWidget: public Ui_ElevationWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ELEVATIONWIDGET_H
