/********************************************************************************
** Form generated from reading UI file 'MarbleNavigationSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARBLENAVIGATIONSETTINGSWIDGET_H
#define UI_MARBLENAVIGATIONSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MarbleNavigationSettingsWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_dragLocation;
    QComboBox *kcfg_dragLocation;
    QCheckBox *kcfg_inertialEarthRotation;
    QCheckBox *kcfg_animateTargetVoyage;
    QCheckBox *kcfg_mouseViewRotation;
    QSpacerItem *spacer;
    QFormLayout *formLayout;
    QLabel *label_onStartup;
    QComboBox *kcfg_onStartup;
    QLabel *label_externalEditor;
    QComboBox *kcfg_externalMapEditor;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *MarbleNavigationSettingsWidget)
    {
        if (MarbleNavigationSettingsWidget->objectName().isEmpty())
            MarbleNavigationSettingsWidget->setObjectName("MarbleNavigationSettingsWidget");
        MarbleNavigationSettingsWidget->resize(333, 257);
        verticalLayout_2 = new QVBoxLayout(MarbleNavigationSettingsWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(MarbleNavigationSettingsWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_dragLocation = new QLabel(groupBox);
        label_dragLocation->setObjectName("label_dragLocation");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_dragLocation->sizePolicy().hasHeightForWidth());
        label_dragLocation->setSizePolicy(sizePolicy);
        label_dragLocation->setMinimumSize(QSize(118, 0));

        horizontalLayout->addWidget(label_dragLocation);

        kcfg_dragLocation = new QComboBox(groupBox);
        kcfg_dragLocation->addItem(QString());
        kcfg_dragLocation->addItem(QString());
        kcfg_dragLocation->setObjectName("kcfg_dragLocation");
        kcfg_dragLocation->setEnabled(false);

        horizontalLayout->addWidget(kcfg_dragLocation);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_inertialEarthRotation = new QCheckBox(groupBox);
        kcfg_inertialEarthRotation->setObjectName("kcfg_inertialEarthRotation");

        verticalLayout->addWidget(kcfg_inertialEarthRotation);

        kcfg_animateTargetVoyage = new QCheckBox(groupBox);
        kcfg_animateTargetVoyage->setObjectName("kcfg_animateTargetVoyage");

        verticalLayout->addWidget(kcfg_animateTargetVoyage);

        kcfg_mouseViewRotation = new QCheckBox(groupBox);
        kcfg_mouseViewRotation->setObjectName("kcfg_mouseViewRotation");

        verticalLayout->addWidget(kcfg_mouseViewRotation);


        verticalLayout_2->addWidget(groupBox);

        spacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(spacer);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_onStartup = new QLabel(MarbleNavigationSettingsWidget);
        label_onStartup->setObjectName("label_onStartup");
        sizePolicy.setHeightForWidth(label_onStartup->sizePolicy().hasHeightForWidth());
        label_onStartup->setSizePolicy(sizePolicy);
        label_onStartup->setMinimumSize(QSize(118, 0));

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_onStartup);

        kcfg_onStartup = new QComboBox(MarbleNavigationSettingsWidget);
        kcfg_onStartup->addItem(QString());
        kcfg_onStartup->addItem(QString());
        kcfg_onStartup->setObjectName("kcfg_onStartup");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_onStartup);

        label_externalEditor = new QLabel(MarbleNavigationSettingsWidget);
        label_externalEditor->setObjectName("label_externalEditor");
        sizePolicy.setHeightForWidth(label_externalEditor->sizePolicy().hasHeightForWidth());
        label_externalEditor->setSizePolicy(sizePolicy);
        label_externalEditor->setMinimumSize(QSize(118, 0));

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_externalEditor);

        kcfg_externalMapEditor = new QComboBox(MarbleNavigationSettingsWidget);
        kcfg_externalMapEditor->addItem(QString());
        kcfg_externalMapEditor->addItem(QString());
        kcfg_externalMapEditor->addItem(QString());
        kcfg_externalMapEditor->addItem(QString());
        kcfg_externalMapEditor->setObjectName("kcfg_externalMapEditor");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_externalMapEditor);


        verticalLayout_2->addLayout(formLayout);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label_dragLocation->setBuddy(kcfg_dragLocation);
        label_onStartup->setBuddy(kcfg_onStartup);
        label_externalEditor->setBuddy(kcfg_onStartup);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MarbleNavigationSettingsWidget);

        QMetaObject::connectSlotsByName(MarbleNavigationSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *MarbleNavigationSettingsWidget)
    {
        groupBox->setTitle(QCoreApplication::translate("MarbleNavigationSettingsWidget", "Dragging and Animation", nullptr));
        label_dragLocation->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&Drag location:", nullptr));
        kcfg_dragLocation->setItemText(0, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Keep Planet Axis Vertically", nullptr));
        kcfg_dragLocation->setItemText(1, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Follow Mouse Pointer", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_dragLocation->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">While dragging the mouse there are two standard behaviours when dealing with a virtual globe:</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The location below mouse pointer will follow the cursor exactly: As a result e.g. the north pole will not stay at the top which can lead to confusion. By default Marble makes sure that north is always up which results in a dragging behaviour where the location below the mouse pointer slightly \"detaches\" from the cursor. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_inertialEarthRotation->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "Use kinetic spinning when dragging the map", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_inertialEarthRotation->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&Inertial globe rotation", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_animateTargetVoyage->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">When searching for a location Marble can either move instantly to the new location or it can show a travel animation from the previous place to the new place.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_animateTargetVoyage->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&Animate voyage to the target", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_mouseViewRotation->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "Use right mouse button to rotate the camera around", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_mouseViewRotation->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&Mouse view rotation", nullptr));
        label_onStartup->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&On startup:", nullptr));
        kcfg_onStartup->setItemText(0, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Show Home Location", nullptr));
        kcfg_onStartup->setItemText(1, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Return to Last Location Visited", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_onStartup->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">By default Marble will display the home location immediately after the application has started. As an alternative it can also show the last position that was active when the user left the application. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_externalEditor->setText(QCoreApplication::translate("MarbleNavigationSettingsWidget", "&External editor:", nullptr));
        kcfg_externalMapEditor->setItemText(0, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Always ask", nullptr));
        kcfg_externalMapEditor->setItemText(1, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Potlatch (Web browser)", nullptr));
        kcfg_externalMapEditor->setItemText(2, QCoreApplication::translate("MarbleNavigationSettingsWidget", "JOSM", nullptr));
        kcfg_externalMapEditor->setItemText(3, QCoreApplication::translate("MarbleNavigationSettingsWidget", "Merkaartor", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_externalMapEditor->setToolTip(QCoreApplication::translate("MarbleNavigationSettingsWidget", "<p>The application that is launched to edit maps. Potlatch (default) requires a web browser with flash support to be installed. When selecting josm or merkaartor, make sure that the respective application is installed.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)MarbleNavigationSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class MarbleNavigationSettingsWidget: public Ui_MarbleNavigationSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARBLENAVIGATIONSETTINGSWIDGET_H
