/********************************************************************************
** Form generated from reading UI file 'EditGroundOverlayDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITGROUNDOVERLAYDIALOG_H
#define UI_EDITGROUNDOVERLAYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "FormattedTextWidget.h"
#include "PlacemarkEditHeader.h"

QT_BEGIN_NAMESPACE

class Ui_UiEditGroundOverlayDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    Marble::PlacemarkEditHeader *m_header;
    QTabWidget *tabWidget;
    QWidget *m_descriptionTab;
    QVBoxLayout *verticalLayout_3;
    Marble::FormattedTextWidget *m_formattedTextWidget;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QLabel *m_northLabel;
    QDoubleSpinBox *m_north;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_4;
    QLabel *m_westLabel;
    QDoubleSpinBox *m_west;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_eastLabel;
    QDoubleSpinBox *m_east;
    QSpacerItem *horizontalSpacer_9;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_4;
    QLabel *m_southLabel;
    QDoubleSpinBox *m_south;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_7;
    QLabel *m_rotationLabel;
    QDoubleSpinBox *m_rotation;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_5;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiEditGroundOverlayDialog)
    {
        if (UiEditGroundOverlayDialog->objectName().isEmpty())
            UiEditGroundOverlayDialog->setObjectName("UiEditGroundOverlayDialog");
        UiEditGroundOverlayDialog->resize(339, 328);
        verticalLayout_2 = new QVBoxLayout(UiEditGroundOverlayDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_header = new Marble::PlacemarkEditHeader(UiEditGroundOverlayDialog);
        m_header->setObjectName("m_header");

        verticalLayout_2->addWidget(m_header);

        tabWidget = new QTabWidget(UiEditGroundOverlayDialog);
        tabWidget->setObjectName("tabWidget");
        m_descriptionTab = new QWidget();
        m_descriptionTab->setObjectName("m_descriptionTab");
        verticalLayout_3 = new QVBoxLayout(m_descriptionTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_formattedTextWidget = new Marble::FormattedTextWidget(m_descriptionTab);
        m_formattedTextWidget->setObjectName("m_formattedTextWidget");

        verticalLayout_3->addWidget(m_formattedTextWidget);

        tabWidget->addTab(m_descriptionTab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout = new QVBoxLayout(tab_2);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer_2 = new QSpacerItem(278, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(80, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        m_northLabel = new QLabel(tab_2);
        m_northLabel->setObjectName("m_northLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_northLabel->sizePolicy().hasHeightForWidth());
        m_northLabel->setSizePolicy(sizePolicy);
        m_northLabel->setMaximumSize(QSize(9, 15));
        QFont font;
        font.setUnderline(true);
        m_northLabel->setFont(font);

        horizontalLayout->addWidget(m_northLabel);

        m_north = new QDoubleSpinBox(tab_2);
        m_north->setObjectName("m_north");
        sizePolicy.setHeightForWidth(m_north->sizePolicy().hasHeightForWidth());
        m_north->setSizePolicy(sizePolicy);
        m_north->setMaximumSize(QSize(92, 23));
        m_north->setDecimals(5);
        m_north->setMinimum(-90.000000000000000);
        m_north->setMaximum(90.000000000000000);

        horizontalLayout->addWidget(m_north);

        horizontalSpacer_3 = new QSpacerItem(88, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer_4 = new QSpacerItem(278, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_8 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_8);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        m_westLabel = new QLabel(tab_2);
        m_westLabel->setObjectName("m_westLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_westLabel->sizePolicy().hasHeightForWidth());
        m_westLabel->setSizePolicy(sizePolicy1);
        m_westLabel->setMaximumSize(QSize(12, 13));
        m_westLabel->setFont(font);

        horizontalLayout_4->addWidget(m_westLabel);

        m_west = new QDoubleSpinBox(tab_2);
        m_west->setObjectName("m_west");
        sizePolicy.setHeightForWidth(m_west->sizePolicy().hasHeightForWidth());
        m_west->setSizePolicy(sizePolicy);
        m_west->setMaximumSize(QSize(99, 23));
        m_west->setDecimals(5);
        m_west->setMinimum(-180.000000000000000);
        m_west->setMaximum(180.000000000000000);

        horizontalLayout_4->addWidget(m_west);


        horizontalLayout_2->addLayout(horizontalLayout_4);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_eastLabel = new QLabel(tab_2);
        m_eastLabel->setObjectName("m_eastLabel");
        sizePolicy.setHeightForWidth(m_eastLabel->sizePolicy().hasHeightForWidth());
        m_eastLabel->setSizePolicy(sizePolicy);
        m_eastLabel->setMaximumSize(QSize(8, 33));
        m_eastLabel->setFont(font);

        horizontalLayout_3->addWidget(m_eastLabel);

        m_east = new QDoubleSpinBox(tab_2);
        m_east->setObjectName("m_east");
        sizePolicy.setHeightForWidth(m_east->sizePolicy().hasHeightForWidth());
        m_east->setSizePolicy(sizePolicy);
        m_east->setMaximumSize(QSize(100, 23));
        m_east->setDecimals(5);
        m_east->setMinimum(-180.000000000000000);
        m_east->setMaximum(180.000000000000000);

        horizontalLayout_3->addWidget(m_east);


        horizontalLayout_2->addLayout(horizontalLayout_3);

        horizontalSpacer_9 = new QSpacerItem(18, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_9);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(278, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_4 = new QSpacerItem(80, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        m_southLabel = new QLabel(tab_2);
        m_southLabel->setObjectName("m_southLabel");
        sizePolicy.setHeightForWidth(m_southLabel->sizePolicy().hasHeightForWidth());
        m_southLabel->setSizePolicy(sizePolicy);
        m_southLabel->setMaximumSize(QSize(9, 32));
        QFont font1;
        font1.setUnderline(true);
        font1.setKerning(false);
        m_southLabel->setFont(font1);

        horizontalLayout_5->addWidget(m_southLabel);

        m_south = new QDoubleSpinBox(tab_2);
        m_south->setObjectName("m_south");
        sizePolicy.setHeightForWidth(m_south->sizePolicy().hasHeightForWidth());
        m_south->setSizePolicy(sizePolicy);
        m_south->setMaximumSize(QSize(92, 23));
        m_south->setDecimals(5);
        m_south->setMinimum(-90.000000000000000);
        m_south->setMaximum(90.000000000000000);

        horizontalLayout_5->addWidget(m_south);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        verticalLayout->addLayout(horizontalLayout_5);

        verticalSpacer = new QSpacerItem(278, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_7 = new QSpacerItem(80, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_7);

        m_rotationLabel = new QLabel(tab_2);
        m_rotationLabel->setObjectName("m_rotationLabel");
        sizePolicy.setHeightForWidth(m_rotationLabel->sizePolicy().hasHeightForWidth());
        m_rotationLabel->setSizePolicy(sizePolicy);
        m_rotationLabel->setMaximumSize(QSize(52, 15));

        horizontalLayout_6->addWidget(m_rotationLabel);

        m_rotation = new QDoubleSpinBox(tab_2);
        m_rotation->setObjectName("m_rotation");
        sizePolicy.setHeightForWidth(m_rotation->sizePolicy().hasHeightForWidth());
        m_rotation->setSizePolicy(sizePolicy);
        m_rotation->setMaximumSize(QSize(76, 23));
        m_rotation->setDecimals(2);
        m_rotation->setMinimum(-360.000000000000000);
        m_rotation->setMaximum(360.000000000000000);

        horizontalLayout_6->addWidget(m_rotation);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);


        verticalLayout->addLayout(horizontalLayout_6);

        verticalSpacer_5 = new QSpacerItem(278, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_5);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_2->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(UiEditGroundOverlayDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(UiEditGroundOverlayDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiEditGroundOverlayDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(UiEditGroundOverlayDialog);
    } // setupUi

    void retranslateUi(QDialog *UiEditGroundOverlayDialog)
    {
        UiEditGroundOverlayDialog->setWindowTitle(QCoreApplication::translate("UiEditGroundOverlayDialog", "Edit ground overlay", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(m_descriptionTab), QCoreApplication::translate("UiEditGroundOverlayDialog", "Description", nullptr));
        m_northLabel->setText(QCoreApplication::translate("UiEditGroundOverlayDialog", "N", nullptr));
        m_westLabel->setText(QCoreApplication::translate("UiEditGroundOverlayDialog", "W", nullptr));
        m_eastLabel->setText(QCoreApplication::translate("UiEditGroundOverlayDialog", "E", nullptr));
        m_southLabel->setText(QCoreApplication::translate("UiEditGroundOverlayDialog", "S", nullptr));
        m_rotationLabel->setText(QCoreApplication::translate("UiEditGroundOverlayDialog", "Rotation", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("UiEditGroundOverlayDialog", "Coordinates", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiEditGroundOverlayDialog: public Ui_UiEditGroundOverlayDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITGROUNDOVERLAYDIALOG_H
