/****************************************************************************
** Meta object code from reading C++ file 'TourPlayback.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/TourPlayback.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TourPlayback.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble12TourPlaybackE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::TourPlayback::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble12TourPlaybackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::TourPlayback",
        "finished",
        "",
        "paused",
        "stopped",
        "progressChanged",
        "updated",
        "GeoDataFeature*",
        "added",
        "GeoDataContainer*",
        "parent",
        "feature",
        "row",
        "removed",
        "const GeoDataFeature*",
        "itemFinished",
        "index",
        "updateTracks",
        "clearTracks",
        "stopTour",
        "showBalloon",
        "GeoDataPlacemark*",
        "hideBalloon",
        "centerOn",
        "GeoDataCoordinates",
        "coordinates",
        "handleFinishedItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(GeoDataFeature *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void(GeoDataContainer *, GeoDataFeature *, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 7, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(const GeoDataFeature *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 11 },
        }}),
        // Signal 'itemFinished'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'updateTracks'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearTracks'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopTour'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showBalloon'
        QtMocHelpers::SlotData<void(GeoDataPlacemark *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'hideBalloon'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'centerOn'
        QtMocHelpers::SlotData<void(const GeoDataCoordinates &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'handleFinishedItem'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TourPlayback, qt_meta_tag_ZN6Marble12TourPlaybackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::TourPlayback::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TourPlaybackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TourPlaybackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble12TourPlaybackE_t>.metaTypes,
    nullptr
} };

void Marble::TourPlayback::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TourPlayback *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->paused(); break;
        case 2: _t->stopped(); break;
        case 3: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->updated((*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[1]))); break;
        case 5: _t->added((*reinterpret_cast<std::add_pointer_t<GeoDataContainer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GeoDataFeature*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->removed((*reinterpret_cast<std::add_pointer_t<const GeoDataFeature*>>(_a[1]))); break;
        case 7: _t->itemFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->updateTracks(); break;
        case 9: _t->clearTracks(); break;
        case 10: _t->stopTour(); break;
        case 11: _t->showBalloon((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark*>>(_a[1]))); break;
        case 12: _t->hideBalloon(); break;
        case 13: _t->centerOn((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 14: _t->handleFinishedItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)()>(_a, &TourPlayback::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)()>(_a, &TourPlayback::paused, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)()>(_a, &TourPlayback::stopped, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)(double )>(_a, &TourPlayback::progressChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)(GeoDataFeature * )>(_a, &TourPlayback::updated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)(GeoDataContainer * , GeoDataFeature * , int )>(_a, &TourPlayback::added, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)(const GeoDataFeature * )>(_a, &TourPlayback::removed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TourPlayback::*)(int )>(_a, &TourPlayback::itemFinished, 7))
            return;
    }
}

const QMetaObject *Marble::TourPlayback::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::TourPlayback::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble12TourPlaybackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::TourPlayback::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Marble::TourPlayback::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::TourPlayback::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::TourPlayback::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::TourPlayback::progressChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::TourPlayback::updated(GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Marble::TourPlayback::added(GeoDataContainer * _t1, GeoDataFeature * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Marble::TourPlayback::removed(const GeoDataFeature * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Marble::TourPlayback::itemFinished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
