/********************************************************************************
** Form generated from reading UI file 'EditBookmarkDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITBOOKMARKDIALOG_H
#define UI_EDITBOOKMARKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include "PlacemarkEditHeader.h"

QT_BEGIN_NAMESPACE

class Ui_UiEditBookmarkDialog
{
public:
    QVBoxLayout *verticalLayout;
    Marble::PlacemarkEditHeader *m_header;
    QFormLayout *formLayout;
    QLabel *description_lbl;
    QTextEdit *m_description;
    QLabel *folder_lbl;
    QHBoxLayout *horizontalLayout;
    QComboBox *m_folders;
    QPushButton *m_newFolderButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UiEditBookmarkDialog)
    {
        if (UiEditBookmarkDialog->objectName().isEmpty())
            UiEditBookmarkDialog->setObjectName("UiEditBookmarkDialog");
        UiEditBookmarkDialog->resize(354, 394);
        verticalLayout = new QVBoxLayout(UiEditBookmarkDialog);
        verticalLayout->setObjectName("verticalLayout");
        m_header = new Marble::PlacemarkEditHeader(UiEditBookmarkDialog);
        m_header->setObjectName("m_header");

        verticalLayout->addWidget(m_header);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        description_lbl = new QLabel(UiEditBookmarkDialog);
        description_lbl->setObjectName("description_lbl");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, description_lbl);

        m_description = new QTextEdit(UiEditBookmarkDialog);
        m_description->setObjectName("m_description");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_description->sizePolicy().hasHeightForWidth());
        m_description->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_description);

        folder_lbl = new QLabel(UiEditBookmarkDialog);
        folder_lbl->setObjectName("folder_lbl");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, folder_lbl);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_folders = new QComboBox(UiEditBookmarkDialog);
        m_folders->setObjectName("m_folders");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_folders->sizePolicy().hasHeightForWidth());
        m_folders->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(m_folders);

        m_newFolderButton = new QPushButton(UiEditBookmarkDialog);
        m_newFolderButton->setObjectName("m_newFolderButton");

        horizontalLayout->addWidget(m_newFolderButton);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        buttonBox = new QDialogButtonBox(UiEditBookmarkDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, buttonBox);


        verticalLayout->addLayout(formLayout);

#if QT_CONFIG(shortcut)
        description_lbl->setBuddy(m_description);
        folder_lbl->setBuddy(m_folders);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_description, m_folders);

        retranslateUi(UiEditBookmarkDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, UiEditBookmarkDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UiEditBookmarkDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UiEditBookmarkDialog);
    } // setupUi

    void retranslateUi(QDialog *UiEditBookmarkDialog)
    {
        UiEditBookmarkDialog->setWindowTitle(QCoreApplication::translate("UiEditBookmarkDialog", "Edit Bookmark", nullptr));
        description_lbl->setText(QCoreApplication::translate("UiEditBookmarkDialog", "&Description:", nullptr));
        m_description->setHtml(QCoreApplication::translate("UiEditBookmarkDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<table border=\"0\" style=\"-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;\">\n"
"<tr>\n"
"<td style=\"border: none;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Ubuntu';\"><br /></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Ubuntu';\"><br /></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-fami"
                        "ly:'Ubuntu';\"><br /></p></td></tr></table></body></html>", nullptr));
        folder_lbl->setText(QCoreApplication::translate("UiEditBookmarkDialog", "&Folder:", nullptr));
        m_newFolderButton->setText(QCoreApplication::translate("UiEditBookmarkDialog", "&Add Folder\342\200\246", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UiEditBookmarkDialog: public Ui_UiEditBookmarkDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITBOOKMARKDIALOG_H
