/****************************************************************************
** Meta object code from reading C++ file 'MapScaleFloatItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/plugins/render/mapscale/MapScaleFloatItem.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MapScaleFloatItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MapScaleFloatItem::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MapScaleFloatItem",
        "readSettings",
        "",
        "writeSettings",
        "toggleRatioScaleVisibility",
        "toggleMinimized"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleRatioScaleVisibility'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMinimized'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MapScaleFloatItem, qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MapScaleFloatItem::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractFloatItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>.metaTypes,
    nullptr
} };

void Marble::MapScaleFloatItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MapScaleFloatItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readSettings(); break;
        case 1: _t->writeSettings(); break;
        case 2: _t->toggleRatioScaleVisibility(); break;
        case 3: _t->toggleMinimized(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Marble::MapScaleFloatItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MapScaleFloatItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble17MapScaleFloatItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DialogConfigurationInterface"))
        return static_cast< DialogConfigurationInterface*>(this);
    if (!strcmp(_clname, "org.kde.Marble.RenderPluginInterface/1.09"))
        return static_cast< Marble::RenderPluginInterface*>(this);
    if (!strcmp(_clname, "org.kde.Marble.DialogConfigurationInterface/1.0"))
        return static_cast< Marble::DialogConfigurationInterface*>(this);
    return AbstractFloatItem::qt_metacast(_clname);
}

int Marble::MapScaleFloatItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractFloatItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
using namespace Marble;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_MapScaleFloatItem[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x20,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'M',  'a',  'p',  'S',  'c',  'a', 
    'l',  'e',  'F',  'l',  'o',  'a',  't',  'I', 
    't',  'e',  'm', 
    // "className"
    0x03,  0x71,  'M',  'a',  'p',  'S',  'c',  'a', 
    'l',  'e',  'F',  'l',  'o',  'a',  't',  'I', 
    't',  'e',  'm', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(Marble::MapScaleFloatItem, MapScaleFloatItem, qt_pluginMetaDataV2_MapScaleFloatItem)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_MapScaleFloatItem[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x20,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'M',  'a',  'p',  'S',  'c',  'a', 
    'l',  'e',  'F',  'l',  'o',  'a',  't',  'I', 
    't',  'e',  'm', 
    // "className"
    0x03,  0x71,  'M',  'a',  'p',  'S',  'c',  'a', 
    'l',  'e',  'F',  'l',  'o',  'a',  't',  'I', 
    't',  'e',  'm', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(Marble::MapScaleFloatItem, MapScaleFloatItem)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
