/****************************************************************************
** Meta object code from reading C++ file 'PositionTracking.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.3/src/lib/marble/PositionTracking.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PositionTracking.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble16PositionTrackingE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::PositionTracking::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble16PositionTrackingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::PositionTracking",
        "gpsLocation",
        "",
        "GeoDataCoordinates",
        "statusChanged",
        "PositionProviderStatus",
        "status",
        "positionProviderPluginChanged",
        "PositionProviderPlugin*",
        "activePlugin",
        "setTrackVisible",
        "visible",
        "saveTrack",
        "fileName",
        "clearTrack",
        "updatePosition",
        "updateStatus",
        "positionProviderPlugin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gpsLocation'
        QtMocHelpers::SignalData<void(const GeoDataCoordinates &, qreal)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QReal, 2 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(PositionProviderStatus)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'positionProviderPluginChanged'
        QtMocHelpers::SignalData<void(PositionProviderPlugin *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setTrackVisible'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'saveTrack'
        QtMocHelpers::SlotData<bool(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'clearTrack'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePosition'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatus'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positionProviderPlugin'
        QtMocHelpers::PropertyData<PositionProviderPlugin*>(17, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PositionTracking, qt_meta_tag_ZN6Marble16PositionTrackingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::PositionTracking::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16PositionTrackingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16PositionTrackingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble16PositionTrackingE_t>.metaTypes,
    nullptr
} };

void Marble::PositionTracking::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PositionTracking *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gpsLocation((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 1: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<PositionProviderStatus>>(_a[1]))); break;
        case 2: _t->positionProviderPluginChanged((*reinterpret_cast<std::add_pointer_t<PositionProviderPlugin*>>(_a[1]))); break;
        case 3: _t->setTrackVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: { bool _r = _t->saveTrack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->clearTrack(); break;
        case 6: _t->d->updatePosition(); break;
        case 7: _t->d->updateStatus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PositionTracking::*)(const GeoDataCoordinates & , qreal )>(_a, &PositionTracking::gpsLocation, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionTracking::*)(PositionProviderStatus )>(_a, &PositionTracking::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PositionTracking::*)(PositionProviderPlugin * )>(_a, &PositionTracking::positionProviderPluginChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PositionProviderPlugin**>(_v) = _t->positionProviderPlugin(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositionProviderPlugin(*reinterpret_cast<PositionProviderPlugin**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::PositionTracking::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::PositionTracking::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble16PositionTrackingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::PositionTracking::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Marble::PositionTracking::gpsLocation(const GeoDataCoordinates & _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Marble::PositionTracking::statusChanged(PositionProviderStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::PositionTracking::positionProviderPluginChanged(PositionProviderPlugin * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
