/****************************************************************************
** Meta object code from reading C++ file 'AnnotatePlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/plugins/render/annotate/AnnotatePlugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AnnotatePlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble14AnnotatePluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::AnnotatePlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble14AnnotatePluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::AnnotatePlugin",
        "placemarkMoved",
        "",
        "nodeAdded",
        "GeoDataCoordinates",
        "coordinates",
        "itemMoved",
        "GeoDataPlacemark*",
        "placemark",
        "mouseMoveGeoPosition",
        "enableModel",
        "enabled",
        "askToRemoveFocusItem",
        "removeFocusItem",
        "clearAnnotations",
        "saveAnnotationFile",
        "loadAnnotationFile",
        "openAnnotationFile",
        "copyItem",
        "cutItem",
        "pasteItem",
        "addTextAnnotation",
        "editTextAnnotation",
        "stopEditingTextAnnotation",
        "result",
        "addOverlay",
        "editOverlay",
        "removeOverlay",
        "updateOverlayFrame",
        "GeoDataGroundOverlay*",
        "overlay",
        "addPolygon",
        "stopEditingPolygon",
        "setAddingPolygonHole",
        "setAddingNodes",
        "editPolygon",
        "selectNode",
        "deleteNode",
        "deselectNodes",
        "deleteSelectedNodes",
        "setAreaAvailable",
        "addPolyline",
        "editPolyline",
        "stopEditingPolyline",
        "setPolylineAvailable",
        "addRelation",
        "OsmPlacemarkData",
        "relationOsmData",
        "downloadOsm"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'placemarkMoved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nodeAdded'
        QtMocHelpers::SignalData<void(const GeoDataCoordinates &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'itemMoved'
        QtMocHelpers::SignalData<void(GeoDataPlacemark *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'mouseMoveGeoPosition'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'enableModel'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'askToRemoveFocusItem'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeFocusItem'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearAnnotations'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveAnnotationFile'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadAnnotationFile'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openAnnotationFile'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'copyItem'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cutItem'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pasteItem'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addTextAnnotation'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editTextAnnotation'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopEditingTextAnnotation'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'addOverlay'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editOverlay'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeOverlay'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateOverlayFrame'
        QtMocHelpers::SlotData<void(GeoDataGroundOverlay *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'addPolygon'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopEditingPolygon'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setAddingPolygonHole'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setAddingNodes'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'editPolygon'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectNode'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteNode'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deselectNodes'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteSelectedNodes'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setAreaAvailable'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPolyline'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editPolyline'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopEditingPolyline'
        QtMocHelpers::SlotData<void(int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setPolylineAvailable'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addRelation'
        QtMocHelpers::SlotData<void(const OsmPlacemarkData &)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'downloadOsm'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AnnotatePlugin, qt_meta_tag_ZN6Marble14AnnotatePluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::AnnotatePlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<RenderPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AnnotatePluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AnnotatePluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble14AnnotatePluginE_t>.metaTypes,
    nullptr
} };

void Marble::AnnotatePlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnnotatePlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->placemarkMoved(); break;
        case 1: _t->nodeAdded((*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates>>(_a[1]))); break;
        case 2: _t->itemMoved((*reinterpret_cast<std::add_pointer_t<GeoDataPlacemark*>>(_a[1]))); break;
        case 3: _t->mouseMoveGeoPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->enableModel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->askToRemoveFocusItem(); break;
        case 6: _t->removeFocusItem(); break;
        case 7: _t->clearAnnotations(); break;
        case 8: _t->saveAnnotationFile(); break;
        case 9: _t->loadAnnotationFile(); break;
        case 10: _t->openAnnotationFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->copyItem(); break;
        case 12: _t->cutItem(); break;
        case 13: _t->pasteItem(); break;
        case 14: _t->addTextAnnotation(); break;
        case 15: _t->editTextAnnotation(); break;
        case 16: _t->stopEditingTextAnnotation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->addOverlay(); break;
        case 18: _t->editOverlay(); break;
        case 19: _t->removeOverlay(); break;
        case 20: _t->updateOverlayFrame((*reinterpret_cast<std::add_pointer_t<GeoDataGroundOverlay*>>(_a[1]))); break;
        case 21: _t->addPolygon(); break;
        case 22: _t->stopEditingPolygon((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setAddingPolygonHole((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setAddingNodes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->editPolygon(); break;
        case 26: _t->selectNode(); break;
        case 27: _t->deleteNode(); break;
        case 28: _t->deselectNodes(); break;
        case 29: _t->deleteSelectedNodes(); break;
        case 30: _t->setAreaAvailable(); break;
        case 31: _t->addPolyline(); break;
        case 32: _t->editPolyline(); break;
        case 33: _t->stopEditingPolyline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setPolylineAvailable(); break;
        case 35: _t->addRelation((*reinterpret_cast<std::add_pointer_t<OsmPlacemarkData>>(_a[1]))); break;
        case 36: _t->downloadOsm(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AnnotatePlugin::*)()>(_a, &AnnotatePlugin::placemarkMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotatePlugin::*)(const GeoDataCoordinates & )>(_a, &AnnotatePlugin::nodeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotatePlugin::*)(GeoDataPlacemark * )>(_a, &AnnotatePlugin::itemMoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AnnotatePlugin::*)(const QString & )>(_a, &AnnotatePlugin::mouseMoveGeoPosition, 3))
            return;
    }
}

const QMetaObject *Marble::AnnotatePlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::AnnotatePlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble14AnnotatePluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.Marble.RenderPluginInterface/1.09"))
        return static_cast< Marble::RenderPluginInterface*>(this);
    return RenderPlugin::qt_metacast(_clname);
}

int Marble::AnnotatePlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = RenderPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void Marble::AnnotatePlugin::placemarkMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::AnnotatePlugin::nodeAdded(const GeoDataCoordinates & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Marble::AnnotatePlugin::itemMoved(GeoDataPlacemark * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Marble::AnnotatePlugin::mouseMoveGeoPosition(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
using namespace Marble;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_AnnotatePlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1d,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'A',  'n',  'n',  'o',  't',  'a', 
    't',  'e',  'P',  'l',  'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x6e,  'A',  'n',  'n',  'o',  't',  'a', 
    't',  'e',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(Marble::AnnotatePlugin, AnnotatePlugin, qt_pluginMetaDataV2_AnnotatePlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_AnnotatePlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1d,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'A',  'n',  'n',  'o',  't',  'a', 
    't',  'e',  'P',  'l',  'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x6e,  'A',  'n',  'n',  'o',  't',  'a', 
    't',  'e',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(Marble::AnnotatePlugin, AnnotatePlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
