/********************************************************************************
** Form generated from reading UI file 'OsmRelationManagerWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OSMRELATIONMANAGERWIDGET_H
#define UI_OSMRELATIONMANAGERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OsmRelationManagerWidgetPrivate
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *m_currentRelations;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_addRelation;

    void setupUi(QWidget *OsmRelationManagerWidgetPrivate)
    {
        if (OsmRelationManagerWidgetPrivate->objectName().isEmpty())
            OsmRelationManagerWidgetPrivate->setObjectName("OsmRelationManagerWidgetPrivate");
        OsmRelationManagerWidgetPrivate->resize(433, 278);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OsmRelationManagerWidgetPrivate->sizePolicy().hasHeightForWidth());
        OsmRelationManagerWidgetPrivate->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(OsmRelationManagerWidgetPrivate);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(OsmRelationManagerWidgetPrivate);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        m_currentRelations = new QTreeWidget(OsmRelationManagerWidgetPrivate);
        m_currentRelations->setObjectName("m_currentRelations");
        m_currentRelations->setEnabled(true);

        verticalLayout->addWidget(m_currentRelations);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_addRelation = new QPushButton(OsmRelationManagerWidgetPrivate);
        m_addRelation->setObjectName("m_addRelation");

        horizontalLayout->addWidget(m_addRelation);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(OsmRelationManagerWidgetPrivate);

        QMetaObject::connectSlotsByName(OsmRelationManagerWidgetPrivate);
    } // setupUi

    void retranslateUi(QWidget *OsmRelationManagerWidgetPrivate)
    {
        label->setText(QCoreApplication::translate("OsmRelationManagerWidgetPrivate", "Current Relations", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = m_currentRelations->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("OsmRelationManagerWidgetPrivate", "Role", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OsmRelationManagerWidgetPrivate", "Type", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OsmRelationManagerWidgetPrivate", "Name", nullptr));
        m_addRelation->setText(QCoreApplication::translate("OsmRelationManagerWidgetPrivate", "Add Relation", nullptr));
        (void)OsmRelationManagerWidgetPrivate;
    } // retranslateUi

};

namespace Ui {
    class OsmRelationManagerWidgetPrivate: public Ui_OsmRelationManagerWidgetPrivate {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OSMRELATIONMANAGERWIDGET_H
