/********************************************************************************
** Form generated from reading UI file 'MonavConfigWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MONAVCONFIGWIDGET_H
#define UI_MONAVCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MonavConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *m_stackedWidget;
    QWidget *m_settingsPage;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *monavTabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_3;
    QFormLayout *formLayout_2;
    QLabel *label_2;
    QComboBox *m_transportTypeComboBox;
    QTableView *m_configureMapsListView;
    QWidget *tab_3;
    QGridLayout *gridLayout_5;
    QTableView *m_installedMapsListView;
    QWidget *tab_2;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *m_continentComboBox;
    QLabel *label_3;
    QComboBox *m_stateComboBox;
    QLabel *m_regionLabel;
    QComboBox *m_regionComboBox;
    QPushButton *m_installButton;
    QLabel *m_statusLabel;
    QWidget *m_progressPage;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_2;
    QLabel *m_progressLabel;
    QProgressBar *m_progressBar;
    QPushButton *m_cancelButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MonavConfigWidget)
    {
        if (MonavConfigWidget->objectName().isEmpty())
            MonavConfigWidget->setObjectName("MonavConfigWidget");
        MonavConfigWidget->resize(296, 304);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MonavConfigWidget->sizePolicy().hasHeightForWidth());
        MonavConfigWidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(MonavConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_stackedWidget = new QStackedWidget(MonavConfigWidget);
        m_stackedWidget->setObjectName("m_stackedWidget");
        m_settingsPage = new QWidget();
        m_settingsPage->setObjectName("m_settingsPage");
        verticalLayout_2 = new QVBoxLayout(m_settingsPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        monavTabWidget = new QTabWidget(m_settingsPage);
        monavTabWidget->setObjectName("monavTabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        sizePolicy.setHeightForWidth(tab->sizePolicy().hasHeightForWidth());
        tab->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(tab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        m_transportTypeComboBox = new QComboBox(tab);
        m_transportTypeComboBox->addItem(QString());
        m_transportTypeComboBox->setObjectName("m_transportTypeComboBox");
        m_transportTypeComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_transportTypeComboBox);


        verticalLayout_3->addLayout(formLayout_2);

        m_configureMapsListView = new QTableView(tab);
        m_configureMapsListView->setObjectName("m_configureMapsListView");
        sizePolicy.setHeightForWidth(m_configureMapsListView->sizePolicy().hasHeightForWidth());
        m_configureMapsListView->setSizePolicy(sizePolicy);
        m_configureMapsListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_configureMapsListView->setAlternatingRowColors(true);
        m_configureMapsListView->horizontalHeader()->setVisible(true);
        m_configureMapsListView->horizontalHeader()->setStretchLastSection(false);
        m_configureMapsListView->verticalHeader()->setVisible(false);
        m_configureMapsListView->verticalHeader()->setStretchLastSection(false);

        verticalLayout_3->addWidget(m_configureMapsListView);

        monavTabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        sizePolicy.setHeightForWidth(tab_3->sizePolicy().hasHeightForWidth());
        tab_3->setSizePolicy(sizePolicy);
        gridLayout_5 = new QGridLayout(tab_3);
        gridLayout_5->setObjectName("gridLayout_5");
        m_installedMapsListView = new QTableView(tab_3);
        m_installedMapsListView->setObjectName("m_installedMapsListView");
        sizePolicy.setHeightForWidth(m_installedMapsListView->sizePolicy().hasHeightForWidth());
        m_installedMapsListView->setSizePolicy(sizePolicy);
        m_installedMapsListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_installedMapsListView->setAlternatingRowColors(true);
        m_installedMapsListView->horizontalHeader()->setVisible(false);
        m_installedMapsListView->horizontalHeader()->setStretchLastSection(false);
        m_installedMapsListView->verticalHeader()->setVisible(false);
        m_installedMapsListView->verticalHeader()->setStretchLastSection(false);

        gridLayout_5->addWidget(m_installedMapsListView, 0, 0, 1, 1);

        monavTabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        formLayout = new QFormLayout(tab_2);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(tab_2);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        m_continentComboBox = new QComboBox(tab_2);
        m_continentComboBox->setObjectName("m_continentComboBox");
        m_continentComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_continentComboBox);

        label_3 = new QLabel(tab_2);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        m_stateComboBox = new QComboBox(tab_2);
        m_stateComboBox->setObjectName("m_stateComboBox");
        m_stateComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_stateComboBox);

        m_regionLabel = new QLabel(tab_2);
        m_regionLabel->setObjectName("m_regionLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, m_regionLabel);

        m_regionComboBox = new QComboBox(tab_2);
        m_regionComboBox->setObjectName("m_regionComboBox");
        m_regionComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_regionComboBox);

        m_installButton = new QPushButton(tab_2);
        m_installButton->setObjectName("m_installButton");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, m_installButton);

        monavTabWidget->addTab(tab_2, QString());

        verticalLayout_2->addWidget(monavTabWidget);

        m_statusLabel = new QLabel(m_settingsPage);
        m_statusLabel->setObjectName("m_statusLabel");

        verticalLayout_2->addWidget(m_statusLabel);

        m_stackedWidget->addWidget(m_settingsPage);
        m_progressPage = new QWidget();
        m_progressPage->setObjectName("m_progressPage");
        gridLayout_3 = new QGridLayout(m_progressPage);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 0, 0, 1, 1);

        m_progressLabel = new QLabel(m_progressPage);
        m_progressLabel->setObjectName("m_progressLabel");
        m_progressLabel->setWordWrap(true);

        gridLayout_3->addWidget(m_progressLabel, 1, 0, 1, 1);

        m_progressBar = new QProgressBar(m_progressPage);
        m_progressBar->setObjectName("m_progressBar");
        m_progressBar->setMaximum(0);
        m_progressBar->setValue(140958);

        gridLayout_3->addWidget(m_progressBar, 2, 0, 1, 1);

        m_cancelButton = new QPushButton(m_progressPage);
        m_cancelButton->setObjectName("m_cancelButton");

        gridLayout_3->addWidget(m_cancelButton, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 3, 0, 1, 1);

        m_stackedWidget->addWidget(m_progressPage);

        verticalLayout->addWidget(m_stackedWidget);


        retranslateUi(MonavConfigWidget);

        m_stackedWidget->setCurrentIndex(0);
        monavTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MonavConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *MonavConfigWidget)
    {
        MonavConfigWidget->setWindowTitle(QCoreApplication::translate("MonavConfigWidget", "Monav Configuration", nullptr));
        label_2->setText(QCoreApplication::translate("MonavConfigWidget", "Transport Type:", nullptr));
        m_transportTypeComboBox->setItemText(0, QCoreApplication::translate("MonavConfigWidget", "Any", nullptr));

        monavTabWidget->setTabText(monavTabWidget->indexOf(tab), QCoreApplication::translate("MonavConfigWidget", "Configure", nullptr));
        monavTabWidget->setTabText(monavTabWidget->indexOf(tab_3), QCoreApplication::translate("MonavConfigWidget", "Manage Maps", nullptr));
        label->setText(QCoreApplication::translate("MonavConfigWidget", "Continent", nullptr));
        label_3->setText(QCoreApplication::translate("MonavConfigWidget", "Country", nullptr));
        m_regionLabel->setText(QCoreApplication::translate("MonavConfigWidget", "Download Variant", nullptr));
        m_installButton->setText(QCoreApplication::translate("MonavConfigWidget", "Install", nullptr));
        monavTabWidget->setTabText(monavTabWidget->indexOf(tab_2), QCoreApplication::translate("MonavConfigWidget", "Install New", nullptr));
        m_statusLabel->setText(QString());
        m_progressLabel->setText(QCoreApplication::translate("MonavConfigWidget", "Nothing to do.", nullptr));
        m_progressBar->setFormat(QCoreApplication::translate("MonavConfigWidget", "%v/%m MB", nullptr));
        m_cancelButton->setText(QCoreApplication::translate("MonavConfigWidget", "Abort", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MonavConfigWidget: public Ui_MonavConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MONAVCONFIGWIDGET_H
