/****************************************************************************
** Meta object code from reading C++ file 'Placemark.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.04.3/src/lib/marble/declarative/Placemark.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Placemark.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble9PlacemarkE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::Placemark::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble9PlacemarkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::Placemark",
        "QML.Element",
        "auto",
        "nameChanged",
        "",
        "coordinatesChanged",
        "descriptionChanged",
        "addressChanged",
        "websiteChanged",
        "wikipediaChanged",
        "openingHoursChanged",
        "wheelchairInfoChanged",
        "wifiAvailabilityChanged",
        "phoneChanged",
        "tagsChanged",
        "routeRelationModelChanged",
        "setName",
        "name",
        "description",
        "address",
        "website",
        "wikipedia",
        "openingHours",
        "coordinates",
        "wheelchairInfo",
        "wifiAvailable",
        "phone",
        "longitude",
        "latitude",
        "tags",
        "routeRelationModel",
        "RouteRelationModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'coordinatesChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addressChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'websiteChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wikipediaChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openingHoursChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wheelchairInfoChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiAvailabilityChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phoneChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tagsChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'routeRelationModelChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'website'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'wikipedia'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'openingHours'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'coordinates'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'wheelchairInfo'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'wifiAvailable'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'phone'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'longitude'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags, 1),
        // property 'latitude'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags, 1),
        // property 'tags'
        QtMocHelpers::PropertyData<QStringList>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags, 10),
        // property 'routeRelationModel'
        QtMocHelpers::PropertyData<RouteRelationModel*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Placemark, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Marble::Placemark::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9PlacemarkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9PlacemarkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble9PlacemarkE_t>.metaTypes,
    nullptr
} };

void Marble::Placemark::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Placemark *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->coordinatesChanged(); break;
        case 2: _t->descriptionChanged(); break;
        case 3: _t->addressChanged(); break;
        case 4: _t->websiteChanged(); break;
        case 5: _t->wikipediaChanged(); break;
        case 6: _t->openingHoursChanged(); break;
        case 7: _t->wheelchairInfoChanged(); break;
        case 8: _t->wifiAvailabilityChanged(); break;
        case 9: _t->phoneChanged(); break;
        case 10: _t->tagsChanged(); break;
        case 11: _t->routeRelationModelChanged(); break;
        case 12: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::coordinatesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::descriptionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::addressChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::websiteChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::wikipediaChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::openingHoursChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::wheelchairInfoChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::wifiAvailabilityChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::phoneChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::tagsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Placemark::*)()>(_a, &Placemark::routeRelationModelChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RouteRelationModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->website(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->wikipedia(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->openingHours(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->coordinates(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->wheelchairInfo(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->wifiAvailable(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->phone(); break;
        case 10: *reinterpret_cast<double*>(_v) = _t->longitude(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->latitude(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->tags(); break;
        case 13: *reinterpret_cast<RouteRelationModel**>(_v) = _t->routeRelationModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Marble::Placemark::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::Placemark::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble9PlacemarkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::Placemark::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Marble::Placemark::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Marble::Placemark::coordinatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Marble::Placemark::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Marble::Placemark::addressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Marble::Placemark::websiteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Marble::Placemark::wikipediaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Marble::Placemark::openingHoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Marble::Placemark::wheelchairInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Marble::Placemark::wifiAvailabilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Marble::Placemark::phoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Marble::Placemark::tagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Marble::Placemark::routeRelationModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
